-- database_updates.sql - تحديثات قاعدة البيانات لإضافة ميزة دخول ولي الأمر

-- إنشاء جدول أولياء الأمور
CREATE TABLE IF NOT EXISTS parents (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    email VARCHAR(100) UNIQUE NOT NULL,
    password VARCHAR(255) NOT NULL,
    phone VARCHAR(20),
    address TEXT,
    national_id VARCHAR(20),
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    is_active BOOLEAN DEFAULT TRUE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إضافة عمود parent_id إلى جدول الطلاب
ALTER TABLE students 
ADD COLUMN parent_id INT,
ADD FOREIGN KEY (parent_id) REFERENCES parents(id) ON DELETE SET NULL;

-- إنشاء جدول ربط الطلاب بأولياء الأمور (في حالة وجود أكثر من ولي أمر للطالب الواحد)
CREATE TABLE IF NOT EXISTS student_parent (
    id INT AUTO_INCREMENT PRIMARY KEY,
    student_id INT NOT NULL,
    parent_id INT NOT NULL,
    relationship ENUM('father', 'mother', 'guardian', 'other') DEFAULT 'father',
    is_primary BOOLEAN DEFAULT FALSE,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (student_id) REFERENCES students(student_id) ON DELETE CASCADE,
    FOREIGN KEY (parent_id) REFERENCES parents(id) ON DELETE CASCADE,
    UNIQUE KEY unique_student_parent (student_id, parent_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول التقييمات/الدرجات
CREATE TABLE IF NOT EXISTS evaluations (
    id INT AUTO_INCREMENT PRIMARY KEY,
    student_id INT NOT NULL,
    teacher_id INT NOT NULL,
    subject_id INT,
    evaluation_type ENUM('quiz', 'exam', 'homework', 'participation', 'project') NOT NULL,
    title VARCHAR(255) NOT NULL,
    score DECIMAL(5,2),
    max_score DECIMAL(5,2) DEFAULT 100.00,
    evaluation_date DATE DEFAULT CURRENT_DATE,
    notes TEXT,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (student_id) REFERENCES students(student_id) ON DELETE CASCADE,
    FOREIGN KEY (teacher_id) REFERENCES teachers(id) ON DELETE CASCADE,
    FOREIGN KEY (subject_id) REFERENCES subjects(subject_id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول الواجبات
CREATE TABLE IF NOT EXISTS assignments (
    id INT AUTO_INCREMENT PRIMARY KEY,
    teacher_id INT NOT NULL,
    subject_id INT,
    group_id INT,
    title VARCHAR(255) NOT NULL,
    description TEXT,
    due_date DATE,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (teacher_id) REFERENCES teachers(id) ON DELETE CASCADE,
    FOREIGN KEY (subject_id) REFERENCES subjects(subject_id) ON DELETE SET NULL,
    FOREIGN KEY (group_id) REFERENCES groups(group_id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول تسليم الواجبات
CREATE TABLE IF NOT EXISTS assignment_submissions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    assignment_id INT NOT NULL,
    student_id INT NOT NULL,
    submission_date DATETIME DEFAULT CURRENT_TIMESTAMP,
    status ENUM('submitted', 'late', 'missing') DEFAULT 'submitted',
    notes TEXT,
    grade DECIMAL(5,2),
    teacher_feedback TEXT,
    FOREIGN KEY (assignment_id) REFERENCES assignments(id) ON DELETE CASCADE,
    FOREIGN KEY (student_id) REFERENCES students(student_id) ON DELETE CASCADE,
    UNIQUE KEY unique_assignment_student (assignment_id, student_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول الرسائل بين المعلمين وأولياء الأمور
CREATE TABLE IF NOT EXISTS parent_teacher_messages (
    id INT AUTO_INCREMENT PRIMARY KEY,
    sender_type ENUM('teacher', 'parent') NOT NULL,
    sender_id INT NOT NULL,
    receiver_type ENUM('teacher', 'parent') NOT NULL,
    receiver_id INT NOT NULL,
    student_id INT,
    subject VARCHAR(255) NOT NULL,
    message TEXT NOT NULL,
    is_read BOOLEAN DEFAULT FALSE,
    sent_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (student_id) REFERENCES students(student_id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول جلسات المحاولات الفاشلة لتسجيل الدخول (للأمان)
CREATE TABLE IF NOT EXISTS login_attempts (
    id INT AUTO_INCREMENT PRIMARY KEY,
    email VARCHAR(100) NOT NULL,
    ip_address VARCHAR(45) NOT NULL,
    user_agent TEXT,
    attempt_time DATETIME DEFAULT CURRENT_TIMESTAMP,
    success BOOLEAN DEFAULT FALSE,
    user_type ENUM('teacher', 'distributor', 'parent')
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إنشاء جدول رموز CSRF
CREATE TABLE IF NOT EXISTS csrf_tokens (
    id INT AUTO_INCREMENT PRIMARY KEY,
    token VARCHAR(255) UNIQUE NOT NULL,
    user_id INT NOT NULL,
    user_type ENUM('teacher', 'distributor', 'parent') NOT NULL,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    expires_at DATETIME NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إضافة فهارس لتحسين الأداء
CREATE INDEX idx_students_parent_id ON students(parent_id);
CREATE INDEX idx_students_teacher_id ON students(teacher_id);
CREATE INDEX idx_attendance_student_date ON attendance(student_id, date);
CREATE INDEX idx_payments_student_date ON payments(student_id, payment_date);
CREATE INDEX idx_evaluations_student_date ON evaluations(student_id, evaluation_date);
CREATE INDEX idx_login_attempts_email_time ON login_attempts(email, attempt_time);
CREATE INDEX idx_csrf_tokens_expires ON csrf_tokens(expires_at);

-- إدراج بيانات تجريبية لأولياء الأمور
INSERT INTO parents (name, email, password, phone, address) VALUES
('أحمد محمد علي', 'ahmed.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567890', 'القاهرة، مصر'),
('فاطمة أحمد', 'fatima.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567891', 'الإسكندرية، مصر'),
('محمد حسن', 'mohamed.parent@example.com', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567892', 'الجيزة، مصر');

-- ربط الطلاب بأولياء الأمور (تحديث الطلاب الموجودين)
-- هذا مثال - يجب تعديله حسب البيانات الفعلية
-- UPDATE students SET parent_id = 1 WHERE student_id = 1;
-- UPDATE students SET parent_id = 2 WHERE student_id = 2;
-- UPDATE students SET parent_id = 3 WHERE student_id = 3;

