<?php
// includes/auth.php - وظائف التحقق من الهوية المحسنة

require_once 'security.php';

/**
 * التحقق من تسجيل دخول المعلم
 */
function checkTeacherAuth() {
    session_start();
    
    if (!checkSessionTimeout()) {
        redirectToLogin();
    }
    
    if (!isset($_SESSION['teacher_id']) || $_SESSION['role'] !== 'teacher') {
        redirectToLogin();
    }
    
    return $_SESSION['teacher_id'];
}

/**
 * التحقق من تسجيل دخول المدير/الموزع
 */
function checkDistributorAuth() {
    session_start();
    
    if (!checkSessionTimeout()) {
        redirectToLogin();
    }
    
    if (!isset($_SESSION['distributor_id']) || $_SESSION['role'] !== 'distributor') {
        redirectToLogin();
    }
    
    return $_SESSION['distributor_id'];
}

/**
 * التحقق من تسجيل دخول ولي الأمر
 */
function checkParentAuth() {
    session_start();
    
    if (!checkSessionTimeout()) {
        redirectToLogin();
    }
    
    if (!isset($_SESSION['parent_id']) || $_SESSION['role'] !== 'parent') {
        redirectToLogin();
    }
    
    return $_SESSION['parent_id'];
}

/**
 * إعادة التوجيه لصفحة تسجيل الدخول
 */
function redirectToLogin() {
    $login_url = '/login.php';
    
    // تحديد المسار النسبي لصفحة تسجيل الدخول
    $current_dir = dirname($_SERVER['SCRIPT_NAME']);
    if (strpos($current_dir, '/teacher') !== false || 
        strpos($current_dir, '/admin') !== false || 
        strpos($current_dir, '/parent') !== false) {
        $login_url = '../login.php';
    }
    
    header("Location: $login_url");
    exit;
}

/**
 * التحقق من صلاحية المستخدم للوصول لمورد معين
 */
function checkResourceAccess($resource_type, $resource_id, $user_type, $user_id) {
    global $pdo;
    
    try {
        switch ($resource_type) {
            case 'student':
                if ($user_type === 'teacher') {
                    $stmt = $pdo->prepare("SELECT student_id FROM students WHERE student_id = ? AND teacher_id = ?");
                    $stmt->execute([$resource_id, $user_id]);
                    return $stmt->fetch() !== false;
                } elseif ($user_type === 'parent') {
                    $stmt = $pdo->prepare("
                        SELECT s.student_id 
                        FROM students s
                        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
                        WHERE s.student_id = ? AND (sp.parent_id = ? OR s.parent_id = ?)
                    ");
                    $stmt->execute([$resource_id, $user_id, $user_id]);
                    return $stmt->fetch() !== false;
                }
                break;
                
            case 'teacher':
                if ($user_type === 'parent') {
                    $stmt = $pdo->prepare("
                        SELECT DISTINCT s.teacher_id 
                        FROM students s
                        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
                        WHERE s.teacher_id = ? AND (sp.parent_id = ? OR s.parent_id = ?)
                    ");
                    $stmt->execute([$resource_id, $user_id, $user_id]);
                    return $stmt->fetch() !== false;
                }
                break;
        }
        
        return false;
    } catch (PDOException $e) {
        error_log("Resource access check error: " . $e->getMessage());
        return false;
    }
}

/**
 * تسجيل نشاط المستخدم
 */
function logUserActivity($user_type, $user_id, $action, $details = null) {
    global $pdo;
    
    try {
        $stmt = $pdo->prepare("
            INSERT INTO user_activity_log (user_type, user_id, action, details, ip_address, user_agent, created_at) 
            VALUES (?, ?, ?, ?, ?, ?, NOW())
        ");
        
        $ip_address = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
        $user_agent = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
        
        $stmt->execute([$user_type, $user_id, $action, $details, $ip_address, $user_agent]);
    } catch (PDOException $e) {
        error_log("Activity log error: " . $e->getMessage());
    }
}

/**
 * إنشاء رمز CSRF للنماذج
 */
function generateCSRFField() {
    if (!isset($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    
    return '<input type="hidden" name="csrf_token" value="' . $_SESSION['csrf_token'] . '">';
}

/**
 * التحقق من رمز CSRF
 */
function validateCSRF($token) {
    return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
}

/**
 * تنظيف وتعقيم البيانات المدخلة
 */
function sanitizeFormData($data) {
    if (is_array($data)) {
        return array_map('sanitizeFormData', $data);
    }
    
    return htmlspecialchars(trim($data), ENT_QUOTES, 'UTF-8');
}

/**
 * التحقق من صحة البيانات المدخلة
 */
function validateInput($data, $rules) {
    $errors = [];
    
    foreach ($rules as $field => $rule) {
        $value = $data[$field] ?? '';
        
        // التحقق من الحقول المطلوبة
        if (isset($rule['required']) && $rule['required'] && empty($value)) {
            $errors[$field] = "هذا الحقل مطلوب";
            continue;
        }
        
        // التحقق من نوع البيانات
        if (!empty($value) && isset($rule['type'])) {
            switch ($rule['type']) {
                case 'email':
                    if (!filter_var($value, FILTER_VALIDATE_EMAIL)) {
                        $errors[$field] = "البريد الإلكتروني غير صحيح";
                    }
                    break;
                    
                case 'phone':
                    if (!preg_match('/^[0-9+\-\s()]+$/', $value)) {
                        $errors[$field] = "رقم الهاتف غير صحيح";
                    }
                    break;
                    
                case 'numeric':
                    if (!is_numeric($value)) {
                        $errors[$field] = "يجب أن يكون رقماً";
                    }
                    break;
                    
                case 'date':
                    if (!strtotime($value)) {
                        $errors[$field] = "التاريخ غير صحيح";
                    }
                    break;
            }
        }
        
        // التحقق من الحد الأدنى والأقصى للطول
        if (!empty($value)) {
            if (isset($rule['min_length']) && strlen($value) < $rule['min_length']) {
                $errors[$field] = "يجب أن يكون على الأقل {$rule['min_length']} أحرف";
            }
            
            if (isset($rule['max_length']) && strlen($value) > $rule['max_length']) {
                $errors[$field] = "يجب أن يكون أقل من {$rule['max_length']} حرف";
            }
        }
    }
    
    return $errors;
}

/**
 * إنشاء كلمة مرور عشوائية آمنة
 */
function generateSecurePassword($length = 12) {
    $chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*';
    $password = '';
    
    for ($i = 0; $i < $length; $i++) {
        $password .= $chars[random_int(0, strlen($chars) - 1)];
    }
    
    return $password;
}
?>

