<?php
// includes/cache.php - نظام التخزين المؤقت

class SimpleCache {
    private $cache_dir;
    private $default_ttl;
    
    public function __construct($cache_dir = null, $default_ttl = 3600) {
        $this->cache_dir = $cache_dir ?: sys_get_temp_dir() . '/td_cache';
        $this->default_ttl = $default_ttl;
        
        // إنشاء مجلد التخزين المؤقت إذا لم يكن موجوداً
        if (!is_dir($this->cache_dir)) {
            mkdir($this->cache_dir, 0755, true);
        }
    }
    
    /**
     * حفظ البيانات في التخزين المؤقت
     */
    public function set($key, $data, $ttl = null) {
        $ttl = $ttl ?: $this->default_ttl;
        $cache_file = $this->getCacheFile($key);
        
        $cache_data = [
            'data' => $data,
            'expires' => time() + $ttl,
            'created' => time()
        ];
        
        return file_put_contents($cache_file, serialize($cache_data)) !== false;
    }
    
    /**
     * استرجاع البيانات من التخزين المؤقت
     */
    public function get($key, $default = null) {
        $cache_file = $this->getCacheFile($key);
        
        if (!file_exists($cache_file)) {
            return $default;
        }
        
        $cache_data = unserialize(file_get_contents($cache_file));
        
        if (!$cache_data || $cache_data['expires'] < time()) {
            $this->delete($key);
            return $default;
        }
        
        return $cache_data['data'];
    }
    
    /**
     * التحقق من وجود البيانات في التخزين المؤقت
     */
    public function has($key) {
        return $this->get($key) !== null;
    }
    
    /**
     * حذف البيانات من التخزين المؤقت
     */
    public function delete($key) {
        $cache_file = $this->getCacheFile($key);
        
        if (file_exists($cache_file)) {
            return unlink($cache_file);
        }
        
        return true;
    }
    
    /**
     * مسح جميع البيانات المخزنة مؤقتاً
     */
    public function clear() {
        $files = glob($this->cache_dir . '/*');
        
        foreach ($files as $file) {
            if (is_file($file)) {
                unlink($file);
            }
        }
        
        return true;
    }
    
    /**
     * تنظيف البيانات المنتهية الصلاحية
     */
    public function cleanup() {
        $files = glob($this->cache_dir . '/*');
        $cleaned = 0;
        
        foreach ($files as $file) {
            if (is_file($file)) {
                $cache_data = unserialize(file_get_contents($file));
                
                if (!$cache_data || $cache_data['expires'] < time()) {
                    unlink($file);
                    $cleaned++;
                }
            }
        }
        
        return $cleaned;
    }
    
    /**
     * الحصول على مسار ملف التخزين المؤقت
     */
    private function getCacheFile($key) {
        $safe_key = md5($key);
        return $this->cache_dir . '/' . $safe_key . '.cache';
    }
    
    /**
     * الحصول على إحصائيات التخزين المؤقت
     */
    public function getStats() {
        $files = glob($this->cache_dir . '/*');
        $total_files = count($files);
        $total_size = 0;
        $expired_files = 0;
        
        foreach ($files as $file) {
            if (is_file($file)) {
                $total_size += filesize($file);
                
                $cache_data = unserialize(file_get_contents($file));
                if (!$cache_data || $cache_data['expires'] < time()) {
                    $expired_files++;
                }
            }
        }
        
        return [
            'total_files' => $total_files,
            'total_size' => $total_size,
            'expired_files' => $expired_files,
            'cache_dir' => $this->cache_dir
        ];
    }
}

// إنشاء مثيل عام للتخزين المؤقت
$cache = new SimpleCache(__DIR__ . '/../cache', 3600); // ساعة واحدة افتراضياً

/**
 * دالة مساعدة للتخزين المؤقت مع callback
 */
function cache_remember($key, $ttl, $callback) {
    global $cache;
    
    $data = $cache->get($key);
    
    if ($data === null) {
        $data = $callback();
        $cache->set($key, $data, $ttl);
    }
    
    return $data;
}

/**
 * تخزين مؤقت للاستعلامات
 */
function cache_query($sql, $params = [], $ttl = 300) {
    global $pdo, $cache;
    
    $cache_key = 'query_' . md5($sql . serialize($params));
    
    return cache_remember($cache_key, $ttl, function() use ($pdo, $sql, $params) {
        try {
            $stmt = $pdo->prepare($sql);
            $stmt->execute($params);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (PDOException $e) {
            error_log("Cache query error: " . $e->getMessage());
            return [];
        }
    });
}

/**
 * تخزين مؤقت للإحصائيات
 */
function cache_stats($user_type, $user_id, $ttl = 600) {
    global $pdo;
    
    $cache_key = "stats_{$user_type}_{$user_id}";
    
    return cache_remember($cache_key, $ttl, function() use ($pdo, $user_type, $user_id) {
        $stats = [];
        
        try {
            switch ($user_type) {
                case 'teacher':
                    // إحصائيات المعلم
                    $stmt = $pdo->prepare("SELECT COUNT(*) as total_students FROM students WHERE teacher_id = ?");
                    $stmt->execute([$user_id]);
                    $stats['total_students'] = $stmt->fetchColumn();
                    
                    $stmt = $pdo->prepare("SELECT SUM(amount_paid) as total_revenue FROM payments p JOIN students s ON p.student_id = s.student_id WHERE s.teacher_id = ?");
                    $stmt->execute([$user_id]);
                    $stats['total_revenue'] = $stmt->fetchColumn() ?: 0;
                    
                    $stmt = $pdo->prepare("
                        SELECT 
                            COUNT(*) as total_sessions,
                            SUM(CASE WHEN status = 'حاضر' THEN 1 ELSE 0 END) as present_sessions
                        FROM attendance a 
                        JOIN students s ON a.student_id = s.student_id 
                        WHERE s.teacher_id = ? AND a.date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
                    ");
                    $stmt->execute([$user_id]);
                    $attendance = $stmt->fetch(PDO::FETCH_ASSOC);
                    $stats['attendance_rate'] = $attendance['total_sessions'] > 0 
                        ? round(($attendance['present_sessions'] / $attendance['total_sessions']) * 100, 1)
                        : 0;
                    break;
                    
                case 'parent':
                    // إحصائيات ولي الأمر
                    $stmt = $pdo->prepare("
                        SELECT COUNT(DISTINCT s.student_id) as total_children
                        FROM students s
                        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
                        WHERE sp.parent_id = ? OR s.parent_id = ?
                    ");
                    $stmt->execute([$user_id, $user_id]);
                    $stats['total_children'] = $stmt->fetchColumn();
                    
                    $stmt = $pdo->prepare("
                        SELECT SUM(due_amount) as total_due
                        FROM payments p
                        JOIN students s ON p.student_id = s.student_id
                        LEFT JOIN student_parent sp ON s.student_id = sp.student_id
                        WHERE (sp.parent_id = ? OR s.parent_id = ?) AND p.due_amount > 0
                    ");
                    $stmt->execute([$user_id, $user_id]);
                    $stats['total_due'] = $stmt->fetchColumn() ?: 0;
                    break;
                    
                case 'distributor':
                    // إحصائيات المدير
                    $stmt = $pdo->prepare("SELECT COUNT(*) as active_teachers FROM teachers WHERE is_active = 1");
                    $stmt->execute();
                    $stats['active_teachers'] = $stmt->fetchColumn();
                    
                    $stmt = $pdo->prepare("SELECT COUNT(*) as total_students FROM students");
                    $stmt->execute();
                    $stats['total_students'] = $stmt->fetchColumn();
                    
                    $stmt = $pdo->prepare("SELECT SUM(amount_paid) as monthly_revenue FROM payments WHERE MONTH(payment_date) = MONTH(CURDATE()) AND YEAR(payment_date) = YEAR(CURDATE())");
                    $stmt->execute();
                    $stats['monthly_revenue'] = $stmt->fetchColumn() ?: 0;
                    break;
            }
            
        } catch (PDOException $e) {
            error_log("Stats cache error: " . $e->getMessage());
        }
        
        return $stats;
    });
}

/**
 * إبطال التخزين المؤقت عند تحديث البيانات
 */
function invalidate_cache($patterns = []) {
    global $cache;
    
    if (empty($patterns)) {
        return $cache->clear();
    }
    
    $cache_dir = $cache->cache_dir ?? sys_get_temp_dir() . '/td_cache';
    $files = glob($cache_dir . '/*');
    
    foreach ($files as $file) {
        $filename = basename($file);
        
        foreach ($patterns as $pattern) {
            if (strpos($filename, md5($pattern)) !== false) {
                unlink($file);
                break;
            }
        }
    }
}

/**
 * تنظيف دوري للتخزين المؤقت
 */
function cleanup_cache() {
    global $cache;
    
    // تنظيف الملفات المنتهية الصلاحية
    $cleaned = $cache->cleanup();
    
    // تنظيف إضافي إذا كان حجم التخزين المؤقت كبيراً
    $stats = $cache->getStats();
    
    if ($stats['total_size'] > 50 * 1024 * 1024) { // 50 MB
        $cache->clear();
        $cleaned = $stats['total_files'];
    }
    
    return $cleaned;
}

// تنظيف دوري (يتم تشغيله بنسبة 1% من الطلبات)
if (rand(1, 100) === 1) {
    cleanup_cache();
}
?>

