<?php
/**
 * فحص حالة التثبيت المحسن
 * يتم تضمين هذا الملف في جميع الصفحات للتأكد من اكتمال التثبيت
 * الإصدار المحسن مع معالجة شاملة للأخطاء
 */

// منع الوصول المباشر
if (!defined('SYSTEM_INIT')) {
    define('SYSTEM_INIT', true);
}

/**
 * فئة إدارة التثبيت
 */
class InstallationManager {
    
    private $installFile;
    private $dbFile;
    private $errors = [];
    
    public function __construct() {
        $this->installFile = __DIR__ . '/.installed';
        $this->dbFile = __DIR__ . '/db.php';
    }
    
    /**
     * التحقق الرئيسي من حالة التثبيت
     */
    public function checkInstallation() {
        $currentScript = basename($_SERVER['SCRIPT_NAME']);
        
        // السماح بالوصول لملفات معينة دون فحص
        $allowedFiles = ['install.php', 'install_fixed.php', 'test-db.php'];
        if (in_array($currentScript, $allowedFiles)) {
            return true;
        }
        
        // التحقق من وجود ملفات التثبيت
        if (!$this->isInstalled()) {
            $this->redirectToInstaller();
            return false;
        }
        
        // التحقق من صحة التثبيت
        if (!$this->validateInstallation()) {
            $this->handleCorruptedInstallation();
            return false;
        }
        
        // منع الوصول لملف التثبيت بعد اكتمال التثبيت
        if ($currentScript === 'install.php' || $currentScript === 'install_fixed.php') {
            $this->blockInstallerAccess();
            return false;
        }
        
        return true;
    }
    
    /**
     * التحقق من وجود ملفات التثبيت
     */
    public function isInstalled() {
        return file_exists($this->installFile) && file_exists($this->dbFile);
    }
    
    /**
     * التحقق من صحة التثبيت
     */
    public function validateInstallation() {
        try {
            // التحقق من ملف معلومات التثبيت
            if (!$this->validateInstallationInfo()) {
                return false;
            }
            
            // التحقق من اتصال قاعدة البيانات
            if (!$this->validateDatabaseConnection()) {
                return false;
            }
            
            // التحقق من وجود الجداول المطلوبة
            if (!$this->validateRequiredTables()) {
                return false;
            }
            
            return true;
            
        } catch (Exception $e) {
            $this->logError('Installation validation error: ' . $e->getMessage());
            return false;
        }
    }
    
    /**
     * التحقق من معلومات التثبيت
     */
    private function validateInstallationInfo() {
        if (!file_exists($this->installFile)) {
            $this->errors[] = 'ملف معلومات التثبيت غير موجود';
            return false;
        }
        
        $content = file_get_contents($this->installFile);
        $info = json_decode($content, true);
        
        if (json_last_error() !== JSON_ERROR_NONE) {
            $this->errors[] = 'ملف معلومات التثبيت تالف';
            return false;
        }
        
        $requiredFields = ['installed_at', 'version', 'admin_email', 'database'];
        foreach ($requiredFields as $field) {
            if (!isset($info[$field])) {
                $this->errors[] = "حقل مطلوب مفقود في معلومات التثبيت: $field";
                return false;
            }
        }
        
        return true;
    }
    
    /**
     * التحقق من اتصال قاعدة البيانات
     */
    private function validateDatabaseConnection() {
        try {
            if (!file_exists($this->dbFile)) {
                $this->errors[] = 'ملف إعدادات قاعدة البيانات غير موجود';
                return false;
            }
            
            // تضمين ملف قاعدة البيانات مع معالجة الأخطاء
            ob_start();
            $result = include $this->dbFile;
            $output = ob_get_clean();
            
            if ($result === false) {
                $this->errors[] = 'خطأ في تحميل ملف إعدادات قاعدة البيانات';
                return false;
            }
            
            // التحقق من وجود متغير الاتصال
            if (!isset($pdo)) {
                $this->errors[] = 'متغير اتصال قاعدة البيانات غير محدد';
                return false;
            }
            
            // اختبار الاتصال
            $stmt = $pdo->query("SELECT 1");
            if ($stmt === false) {
                $this->errors[] = 'فشل في اختبار اتصال قاعدة البيانات';
                return false;
            }
            
            return true;
            
        } catch (PDOException $e) {
            $this->errors[] = 'خطأ في اتصال قاعدة البيانات: ' . $e->getMessage();
            $this->logError('Database connection error: ' . $e->getMessage());
            return false;
        } catch (Exception $e) {
            $this->errors[] = 'خطأ عام في التحقق من قاعدة البيانات: ' . $e->getMessage();
            $this->logError('General database validation error: ' . $e->getMessage());
            return false;
        }
    }
    
    /**
     * التحقق من وجود الجداول المطلوبة
     */
    private function validateRequiredTables() {
        try {
            require_once $this->dbFile;
            
            $requiredTables = [
                'distributors',
                'teachers', 
                'students',
                'subjects',
                'groups',
                'attendance',
                'payments',
                'parents',
                'student_parent',
                'evaluations',
                'assignments',
                'assignment_submissions',
                'parent_teacher_messages',
                'notifications',
                'schedule'
            ];
            
            $missingTables = [];
            
            foreach ($requiredTables as $table) {
                $stmt = $pdo->prepare("SHOW TABLES LIKE ?");
                $stmt->execute([$table]);
                if (!$stmt->fetch()) {
                    $missingTables[] = $table;
                }
            }
            
            if (!empty($missingTables)) {
                $this->errors[] = 'جداول مفقودة: ' . implode(', ', $missingTables);
                return false;
            }
            
            return true;
            
        } catch (Exception $e) {
            $this->errors[] = 'خطأ في التحقق من الجداول: ' . $e->getMessage();
            $this->logError('Table validation error: ' . $e->getMessage());
            return false;
        }
    }
    
    /**
     * إعادة التوجيه إلى صفحة التثبيت
     */
    private function redirectToInstaller() {
        $protocol = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http';
        $host = $_SERVER['HTTP_HOST'];
        $path = dirname($_SERVER['SCRIPT_NAME']);
        
        // البحث عن ملف التثبيت المناسب
        $installerFile = 'install_fixed.php';
        if (!file_exists($installerFile)) {
            $installerFile = 'install.php';
        }
        
        $installUrl = "$protocol://$host$path/$installerFile";
        
        header("Location: $installUrl");
        exit('النظام غير مثبت. يتم إعادة التوجيه إلى صفحة التثبيت...');
    }
    
    /**
     * منع الوصول لملف التثبيت
     */
    private function blockInstallerAccess() {
        http_response_code(403);
        $this->displayError(
            'الوصول محظور',
            'النظام مثبت بالفعل. الوصول لملف التثبيت محظور لأسباب أمنية.',
            'إذا كنت تريد إعادة التثبيت، احذف ملف includes/.installed أولاً.'
        );
        exit;
    }
    
    /**
     * معالجة التثبيت التالف
     */
    private function handleCorruptedInstallation() {
        $this->logError('Corrupted installation detected: ' . implode(', ', $this->errors));
        
        $this->displayError(
            'خطأ في التثبيت',
            'تم اكتشاف مشاكل في التثبيت الحالي.',
            'الأخطاء المكتشفة: ' . implode('<br>', $this->errors) . 
            '<br><br>يرجى إعادة تشغيل عملية التثبيت أو الاتصال بالدعم الفني.'
        );
        exit;
    }
    
    /**
     * عرض صفحة خطأ
     */
    private function displayError($title, $message, $details = '') {
        ?>
        <!DOCTYPE html>
        <html lang="ar" dir="rtl">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title><?= htmlspecialchars($title) ?></title>
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
            <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
            <style>
                body {
                    background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
                    min-height: 100vh;
                    display: flex;
                    align-items: center;
                    justify-content: center;
                    font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
                }
                .error-container {
                    max-width: 600px;
                    background: white;
                    border-radius: 15px;
                    box-shadow: 0 20px 40px rgba(0,0,0,0.1);
                    overflow: hidden;
                }
                .error-header {
                    background: linear-gradient(135deg, #dc3545 0%, #c82333 100%);
                    color: white;
                    padding: 30px;
                    text-align: center;
                }
                .error-body {
                    padding: 40px;
                    text-align: center;
                }
            </style>
        </head>
        <body>
            <div class="error-container">
                <div class="error-header">
                    <i class="fas fa-exclamation-triangle fa-3x mb-3"></i>
                    <h1><?= htmlspecialchars($title) ?></h1>
                </div>
                <div class="error-body">
                    <p class="lead"><?= htmlspecialchars($message) ?></p>
                    <?php if ($details): ?>
                        <div class="alert alert-warning text-start mt-4">
                            <?= $details ?>
                        </div>
                    <?php endif; ?>
                    <div class="mt-4">
                        <a href="install_fixed.php" class="btn btn-primary me-2">
                            <i class="fas fa-redo me-2"></i>إعادة التثبيت
                        </a>
                        <a href="mailto:support@example.com" class="btn btn-outline-secondary">
                            <i class="fas fa-envelope me-2"></i>الدعم الفني
                        </a>
                    </div>
                </div>
            </div>
        </body>
        </html>
        <?php
    }
    
    /**
     * تسجيل الأخطاء
     */
    private function logError($message) {
        $logFile = __DIR__ . '/../logs/error.log';
        
        // إنشاء مجلد logs إذا لم يكن موجوداً
        $logDir = dirname($logFile);
        if (!is_dir($logDir)) {
            mkdir($logDir, 0755, true);
        }
        
        $timestamp = date('Y-m-d H:i:s');
        $logMessage = "[$timestamp] [INSTALL_CHECK] $message" . PHP_EOL;
        
        file_put_contents($logFile, $logMessage, FILE_APPEND | LOCK_EX);
    }
    
    /**
     * الحصول على معلومات التثبيت
     */
    public function getInstallationInfo() {
        if (!file_exists($this->installFile)) {
            return null;
        }
        
        $content = file_get_contents($this->installFile);
        return json_decode($content, true);
    }
    
    /**
     * التحقق من إصدار النظام
     */
    public function getSystemVersion() {
        $info = $this->getInstallationInfo();
        return $info && isset($info['version']) ? $info['version'] : 'غير محدد';
    }
    
    /**
     * التحقق من تاريخ التثبيت
     */
    public function getInstallationDate() {
        $info = $this->getInstallationInfo();
        return $info && isset($info['installed_at']) ? $info['installed_at'] : null;
    }
    
    /**
     * إنشاء تقرير حالة النظام
     */
    public function getSystemStatus() {
        return [
            'installed' => $this->isInstalled(),
            'database_config' => file_exists($this->dbFile),
            'database_connection' => $this->validateDatabaseConnection(),
            'required_tables' => $this->validateRequiredTables(),
            'version' => $this->getSystemVersion(),
            'install_date' => $this->getInstallationDate(),
            'errors' => $this->errors
        ];
    }
    
    /**
     * تنظيف الملفات المؤقتة والسجلات القديمة
     */
    public function cleanup() {
        try {
            // تنظيف السجلات القديمة (أكثر من 30 يوم)
            $logFile = __DIR__ . '/../logs/error.log';
            if (file_exists($logFile)) {
                $lines = file($logFile);
                $cleanLines = [];
                $cutoffDate = date('Y-m-d', strtotime('-30 days'));
                
                foreach ($lines as $line) {
                    if (preg_match('/\[(\d{4}-\d{2}-\d{2})/', $line, $matches)) {
                        if ($matches[1] >= $cutoffDate) {
                            $cleanLines[] = $line;
                        }
                    }
                }
                
                file_put_contents($logFile, implode('', $cleanLines));
            }
            
            // تنظيف ملفات التخزين المؤقت
            $cacheDir = __DIR__ . '/../cache';
            if (is_dir($cacheDir)) {
                $files = glob($cacheDir . '/*');
                foreach ($files as $file) {
                    if (is_file($file) && filemtime($file) < strtotime('-1 day')) {
                        unlink($file);
                    }
                }
            }
            
            return true;
            
        } catch (Exception $e) {
            $this->logError('Cleanup error: ' . $e->getMessage());
            return false;
        }
    }
}

// إنشاء مثيل من مدير التثبيت وتشغيل الفحص
if (!defined('SKIP_INSTALL_CHECK')) {
    $installManager = new InstallationManager();
    $installManager->checkInstallation();
    
    // تنظيف دوري (مرة واحدة يومياً)
    $lastCleanup = @filemtime(__DIR__ . '/../cache/.last_cleanup');
    if (!$lastCleanup || $lastCleanup < strtotime('-1 day')) {
        $installManager->cleanup();
        touch(__DIR__ . '/../cache/.last_cleanup');
    }
}

/**
 * دوال مساعدة عامة
 */

/**
 * الحصول على معلومات التثبيت
 */
function getInstallationInfo() {
    global $installManager;
    return $installManager ? $installManager->getInstallationInfo() : null;
}

/**
 * التحقق من إصدار النظام
 */
function checkSystemVersion() {
    global $installManager;
    return $installManager ? $installManager->getSystemVersion() : 'غير محدد';
}

/**
 * التحقق من تاريخ التثبيت
 */
function getInstallationDate() {
    global $installManager;
    return $installManager ? $installManager->getInstallationDate() : null;
}

/**
 * الحصول على حالة النظام
 */
function getSystemStatus() {
    global $installManager;
    return $installManager ? $installManager->getSystemStatus() : [];
}
?>

