<?php
// includes/performance.php - أدوات تحسين الأداء

/**
 * ضغط الإخراج
 */
function enable_compression() {
    if (!ob_get_level() && extension_loaded('zlib') && !ini_get('zlib.output_compression')) {
        ob_start('ob_gzhandler');
    }
}

/**
 * تعيين رؤوس التخزين المؤقت للمتصفح
 */
function set_cache_headers($max_age = 3600, $etag = null) {
    // تعيين رؤوس التحكم في التخزين المؤقت
    header("Cache-Control: public, max-age=$max_age");
    header("Expires: " . gmdate('D, d M Y H:i:s', time() + $max_age) . ' GMT');
    
    // تعيين ETag إذا تم توفيره
    if ($etag) {
        header("ETag: \"$etag\"");
        
        // التحقق من If-None-Match
        if (isset($_SERVER['HTTP_IF_NONE_MATCH']) && 
            trim($_SERVER['HTTP_IF_NONE_MATCH'], '"') === $etag) {
            http_response_code(304);
            exit;
        }
    }
    
    // تعيين Last-Modified
    $last_modified = gmdate('D, d M Y H:i:s', time()) . ' GMT';
    header("Last-Modified: $last_modified");
}

/**
 * تحسين الاستعلامات بالتجميع
 */
class QueryOptimizer {
    private $pdo;
    private $batch_queries = [];
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }
    
    /**
     * إضافة استعلام للدفعة
     */
    public function addQuery($sql, $params = []) {
        $this->batch_queries[] = ['sql' => $sql, 'params' => $params];
    }
    
    /**
     * تنفيذ جميع الاستعلامات في دفعة واحدة
     */
    public function executeBatch() {
        $results = [];
        
        try {
            $this->pdo->beginTransaction();
            
            foreach ($this->batch_queries as $query) {
                $stmt = $this->pdo->prepare($query['sql']);
                $stmt->execute($query['params']);
                $results[] = $stmt->fetchAll(PDO::FETCH_ASSOC);
            }
            
            $this->pdo->commit();
            $this->batch_queries = []; // مسح الدفعة
            
        } catch (PDOException $e) {
            $this->pdo->rollBack();
            error_log("Batch query error: " . $e->getMessage());
            throw $e;
        }
        
        return $results;
    }
    
    /**
     * تحسين استعلام SELECT بإضافة LIMIT تلقائياً
     */
    public function optimizeSelect($sql, $params = [], $limit = 1000) {
        // إضافة LIMIT إذا لم يكن موجوداً
        if (stripos($sql, 'LIMIT') === false && stripos($sql, 'SELECT') === 0) {
            $sql .= " LIMIT $limit";
        }
        
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute($params);
        
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}

/**
 * تحسين الصور
 */
class ImageOptimizer {
    /**
     * ضغط الصورة
     */
    public static function compressImage($source, $destination, $quality = 80) {
        $info = getimagesize($source);
        
        if (!$info) {
            return false;
        }
        
        $mime = $info['mime'];
        
        switch ($mime) {
            case 'image/jpeg':
                $image = imagecreatefromjpeg($source);
                break;
            case 'image/png':
                $image = imagecreatefrompng($source);
                break;
            case 'image/gif':
                $image = imagecreatefromgif($source);
                break;
            default:
                return false;
        }
        
        // حفظ الصورة المضغوطة
        switch ($mime) {
            case 'image/jpeg':
                return imagejpeg($image, $destination, $quality);
            case 'image/png':
                return imagepng($image, $destination, 9 - round($quality / 10));
            case 'image/gif':
                return imagegif($image, $destination);
        }
        
        imagedestroy($image);
        return false;
    }
    
    /**
     * تغيير حجم الصورة
     */
    public static function resizeImage($source, $destination, $max_width, $max_height) {
        $info = getimagesize($source);
        
        if (!$info) {
            return false;
        }
        
        list($width, $height) = $info;
        
        // حساب الأبعاد الجديدة
        $ratio = min($max_width / $width, $max_height / $height);
        $new_width = round($width * $ratio);
        $new_height = round($height * $ratio);
        
        // إنشاء الصورة الجديدة
        $new_image = imagecreatetruecolor($new_width, $new_height);
        
        // الحفاظ على الشفافية للـ PNG
        if ($info['mime'] === 'image/png') {
            imagealphablending($new_image, false);
            imagesavealpha($new_image, true);
        }
        
        $source_image = null;
        switch ($info['mime']) {
            case 'image/jpeg':
                $source_image = imagecreatefromjpeg($source);
                break;
            case 'image/png':
                $source_image = imagecreatefrompng($source);
                break;
            case 'image/gif':
                $source_image = imagecreatefromgif($source);
                break;
        }
        
        if (!$source_image) {
            return false;
        }
        
        // تغيير الحجم
        imagecopyresampled($new_image, $source_image, 0, 0, 0, 0, 
                          $new_width, $new_height, $width, $height);
        
        // حفظ الصورة
        $result = false;
        switch ($info['mime']) {
            case 'image/jpeg':
                $result = imagejpeg($new_image, $destination, 85);
                break;
            case 'image/png':
                $result = imagepng($new_image, $destination, 6);
                break;
            case 'image/gif':
                $result = imagegif($new_image, $destination);
                break;
        }
        
        imagedestroy($new_image);
        imagedestroy($source_image);
        
        return $result;
    }
}

/**
 * مراقب الأداء
 */
class PerformanceMonitor {
    private static $start_time;
    private static $start_memory;
    private static $queries = [];
    
    /**
     * بدء المراقبة
     */
    public static function start() {
        self::$start_time = microtime(true);
        self::$start_memory = memory_get_usage();
    }
    
    /**
     * تسجيل استعلام
     */
    public static function logQuery($sql, $execution_time) {
        self::$queries[] = [
            'sql' => $sql,
            'time' => $execution_time,
            'timestamp' => microtime(true)
        ];
    }
    
    /**
     * الحصول على إحصائيات الأداء
     */
    public static function getStats() {
        $end_time = microtime(true);
        $end_memory = memory_get_usage();
        
        return [
            'execution_time' => round(($end_time - self::$start_time) * 1000, 2), // بالميلي ثانية
            'memory_usage' => round(($end_memory - self::$start_memory) / 1024, 2), // بالكيلوبايت
            'peak_memory' => round(memory_get_peak_usage() / 1024, 2), // بالكيلوبايت
            'query_count' => count(self::$queries),
            'total_query_time' => round(array_sum(array_column(self::$queries, 'time')) * 1000, 2),
            'queries' => self::$queries
        ];
    }
    
    /**
     * عرض إحصائيات الأداء (للتطوير فقط)
     */
    public static function displayStats() {
        if (!defined('DEBUG') || !DEBUG) {
            return;
        }
        
        $stats = self::getStats();
        
        echo "<!-- Performance Stats:\n";
        echo "Execution Time: {$stats['execution_time']}ms\n";
        echo "Memory Usage: {$stats['memory_usage']}KB\n";
        echo "Peak Memory: {$stats['peak_memory']}KB\n";
        echo "Query Count: {$stats['query_count']}\n";
        echo "Total Query Time: {$stats['total_query_time']}ms\n";
        echo "-->";
    }
}

/**
 * تحسين CSS و JavaScript
 */
class AssetOptimizer {
    /**
     * ضغط CSS
     */
    public static function minifyCSS($css) {
        // إزالة التعليقات
        $css = preg_replace('!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css);
        
        // إزالة المسافات الزائدة
        $css = str_replace(["\r\n", "\r", "\n", "\t", '  ', '    ', '    '], '', $css);
        
        // إزالة المسافات حول الرموز
        $css = str_replace(['; ', ' ;', ' {', '{ ', '} ', ' }', ': ', ' :', ', ', ' ,'], 
                          [';', ';', '{', '{', '}', '}', ':', ':', ',', ','], $css);
        
        return trim($css);
    }
    
    /**
     * ضغط JavaScript
     */
    public static function minifyJS($js) {
        // إزالة التعليقات أحادية السطر
        $js = preg_replace('/\/\/.*$/m', '', $js);
        
        // إزالة التعليقات متعددة الأسطر
        $js = preg_replace('/\/\*[\s\S]*?\*\//', '', $js);
        
        // إزالة المسافات الزائدة
        $js = preg_replace('/\s+/', ' ', $js);
        
        // إزالة المسافات حول الرموز
        $js = str_replace([' = ', ' + ', ' - ', ' * ', ' / ', ' == ', ' != ', ' && ', ' || '], 
                         ['=', '+', '-', '*', '/', '==', '!=', '&&', '||'], $js);
        
        return trim($js);
    }
    
    /**
     * دمج ملفات CSS
     */
    public static function combineCSS($files, $output_file) {
        $combined = '';
        
        foreach ($files as $file) {
            if (file_exists($file)) {
                $css = file_get_contents($file);
                $combined .= self::minifyCSS($css) . "\n";
            }
        }
        
        return file_put_contents($output_file, $combined);
    }
    
    /**
     * دمج ملفات JavaScript
     */
    public static function combineJS($files, $output_file) {
        $combined = '';
        
        foreach ($files as $file) {
            if (file_exists($file)) {
                $js = file_get_contents($file);
                $combined .= self::minifyJS($js) . ";\n";
            }
        }
        
        return file_put_contents($output_file, $combined);
    }
}

/**
 * تحسين قاعدة البيانات
 */
class DatabaseOptimizer {
    private $pdo;
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }
    
    /**
     * تحليل الجداول
     */
    public function analyzeTables() {
        try {
            $stmt = $this->pdo->query("SHOW TABLES");
            $tables = $stmt->fetchAll(PDO::FETCH_COLUMN);
            
            foreach ($tables as $table) {
                $this->pdo->exec("ANALYZE TABLE `$table`");
            }
            
            return true;
        } catch (PDOException $e) {
            error_log("Table analysis error: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * تحسين الجداول
     */
    public function optimizeTables() {
        try {
            $stmt = $this->pdo->query("SHOW TABLES");
            $tables = $stmt->fetchAll(PDO::FETCH_COLUMN);
            
            foreach ($tables as $table) {
                $this->pdo->exec("OPTIMIZE TABLE `$table`");
            }
            
            return true;
        } catch (PDOException $e) {
            error_log("Table optimization error: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * الحصول على إحصائيات قاعدة البيانات
     */
    public function getDatabaseStats() {
        try {
            $stats = [];
            
            // حجم قاعدة البيانات
            $stmt = $this->pdo->query("
                SELECT 
                    ROUND(SUM(data_length + index_length) / 1024 / 1024, 2) AS db_size_mb
                FROM information_schema.tables 
                WHERE table_schema = DATABASE()
            ");
            $stats['database_size_mb'] = $stmt->fetchColumn();
            
            // عدد الجداول
            $stmt = $this->pdo->query("
                SELECT COUNT(*) 
                FROM information_schema.tables 
                WHERE table_schema = DATABASE()
            ");
            $stats['table_count'] = $stmt->fetchColumn();
            
            // الاستعلامات البطيئة
            $stmt = $this->pdo->query("SHOW GLOBAL STATUS LIKE 'Slow_queries'");
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            $stats['slow_queries'] = $result['Value'] ?? 0;
            
            return $stats;
        } catch (PDOException $e) {
            error_log("Database stats error: " . $e->getMessage());
            return [];
        }
    }
}

// بدء مراقبة الأداء
PerformanceMonitor::start();

// تفعيل الضغط
enable_compression();
?>

