<?php
/**
 * ملف الأمان والحماية - النسخة الكاملة المحسنة
 * تم إضافة الدالة المفقودة cleanupExpiredTokens()
 * تم إزالة علامة الإغلاق ?> لمنع مشكلة headers already sent
 */

// منع الوصول المباشر
if (!defined('INCLUDED_FROM_APP')) {
    define('INCLUDED_FROM_APP', true);
}

/**
 * التحقق من انتهاء صلاحية الجلسة
 */
function checkSessionTimeout() {
    // إذا لم تكن هناك جلسة نشطة، إرجاع false
    if (session_status() == PHP_SESSION_NONE) {
        return false;
    }
    
    // تعيين مهلة الجلسة (30 دقيقة)
    $timeout_duration = 1800; // 30 دقيقة بالثواني
    
    // إذا كانت هذه أول زيارة، تعيين وقت آخر نشاط
    if (!isset($_SESSION['last_activity'])) {
        $_SESSION['last_activity'] = time();
        return true;
    }
    
    // التحقق من انتهاء صلاحية الجلسة
    if ((time() - $_SESSION['last_activity']) > $timeout_duration) {
        // انتهت صلاحية الجلسة
        session_unset();
        session_destroy();
        return false;
    }
    
    // تحديث وقت آخر نشاط
    $_SESSION['last_activity'] = time();
    return true;
}

/**
 * التحقق من صحة رمز CSRF
 */
function validateCSRFToken($token) {
    if (!isset($_SESSION['csrf_token'])) {
        return false;
    }
    
    return hash_equals($_SESSION['csrf_token'], $token);
}

/**
 * إنشاء رمز CSRF جديد
 */
function generateCSRFToken() {
    if (!isset($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    return $_SESSION['csrf_token'];
}

/**
 * تنظيف البيانات المدخلة
 */
function sanitizeInput($input) {
    if (is_array($input)) {
        return array_map('sanitizeInput', $input);
    }
    
    $input = trim($input);
    $input = stripslashes($input);
    $input = htmlspecialchars($input, ENT_QUOTES, 'UTF-8');
    return $input;
}

/**
 * التحقق من صحة البريد الإلكتروني
 */
function validateEmail($email) {
    return filter_var($email, FILTER_VALIDATE_EMAIL) !== false;
}

/**
 * التحقق من قوة كلمة المرور
 */
function validatePassword($password) {
    $errors = [];
    
    if (strlen($password) < 8) {
        $errors[] = 'كلمة المرور يجب أن تكون 8 أحرف على الأقل';
    }
    
    if (!preg_match('/[A-Z]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على حرف كبير واحد على الأقل';
    }
    
    if (!preg_match('/[a-z]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على حرف صغير واحد على الأقل';
    }
    
    if (!preg_match('/[0-9]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على رقم واحد على الأقل';
    }
    
    return $errors;
}

/**
 * تسجيل محاولات تسجيل الدخول
 */
function logLoginAttempt($email, $success = false, $user_type = 'unknown') {
    global $pdo;
    
    try {
        // التحقق من وجود الجدول أولاً
        if (!tableExists('login_attempts')) {
            return;
        }
        
        $stmt = $pdo->prepare("
            INSERT INTO login_attempts (email, ip_address, user_agent, success, user_type) 
            VALUES (?, ?, ?, ?, ?)
        ");
        
        $stmt->execute([
            $email,
            $_SERVER['REMOTE_ADDR'] ?? 'unknown',
            $_SERVER['HTTP_USER_AGENT'] ?? 'unknown',
            $success ? 1 : 0,
            $user_type
        ]);
    } catch (Exception $e) {
        // تسجيل الخطأ في ملف السجل بدلاً من عرضه
        error_log("Error logging login attempt: " . $e->getMessage());
    }
}

/**
 * التحقق من عدد محاولات تسجيل الدخول الفاشلة
 */
function checkLoginAttempts($email, $max_attempts = 5, $lockout_time = 900) {
    global $pdo;
    
    try {
        // التحقق من وجود الجدول أولاً
        if (!tableExists('login_attempts')) {
            return true; // السماح إذا لم يكن الجدول موجوداً
        }
        
        $stmt = $pdo->prepare("
            SELECT COUNT(*) as attempts 
            FROM login_attempts 
            WHERE email = ? 
            AND success = 0 
            AND attempt_time > DATE_SUB(NOW(), INTERVAL ? SECOND)
        ");
        
        $stmt->execute([$email, $lockout_time]);
        $result = $stmt->fetch();
        
        return $result['attempts'] < $max_attempts;
    } catch (Exception $e) {
        // في حالة الخطأ، السماح بالمحاولة
        error_log("Error checking login attempts: " . $e->getMessage());
        return true;
    }
}

/**
 * تنظيف محاولات تسجيل الدخول القديمة
 */
function cleanupOldLoginAttempts() {
    global $pdo;
    
    try {
        // التحقق من وجود الجدول أولاً
        if (!tableExists('login_attempts')) {
            return;
        }
        
        $stmt = $pdo->prepare("
            DELETE FROM login_attempts 
            WHERE attempt_time < DATE_SUB(NOW(), INTERVAL 24 HOUR)
        ");
        $stmt->execute();
    } catch (Exception $e) {
        error_log("Error cleaning up login attempts: " . $e->getMessage());
    }
}

/**
 * تنظيف الرموز المنتهية الصلاحية (الدالة المفقودة)
 * هذه الدالة كانت مفقودة وتسبب في الخطأ Fatal Error
 */
function cleanupExpiredTokens() {
    global $pdo;
    
    try {
        // تنظيف رموز إعادة تعيين كلمة المرور المنتهية الصلاحية
        if (tableExists('password_reset_tokens')) {
            $stmt = $pdo->prepare("
                DELETE FROM password_reset_tokens 
                WHERE expires_at < NOW()
            ");
            $stmt->execute();
        }
        
        // تنظيف رموز التحقق المنتهية الصلاحية
        if (tableExists('verification_tokens')) {
            $stmt = $pdo->prepare("
                DELETE FROM verification_tokens 
                WHERE expires_at < NOW()
            ");
            $stmt->execute();
        }
        
        // تنظيف رموز CSRF القديمة (إذا كانت مخزنة في قاعدة البيانات)
        if (tableExists('csrf_tokens')) {
            $stmt = $pdo->prepare("
                DELETE FROM csrf_tokens 
                WHERE created_at < DATE_SUB(NOW(), INTERVAL 2 HOUR)
            ");
            $stmt->execute();
        }
        
        // تنظيف الجلسات المنتهية الصلاحية
        cleanupExpiredSessions();
        
    } catch (Exception $e) {
        error_log("Error cleaning up expired tokens: " . $e->getMessage());
    }
}

/**
 * إنشاء جلسة آمنة
 */
function createSecureSession($user_id, $user_type) {
    // تجديد معرف الجلسة لمنع session fixation
    session_regenerate_id(true);
    
    // تعيين بيانات الجلسة
    $_SESSION['user_id'] = $user_id;
    $_SESSION['user_type'] = $user_type;
    $_SESSION['login_time'] = time();
    $_SESSION['last_activity'] = time();
    $_SESSION['ip_address'] = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
    $_SESSION['user_agent'] = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
    
    // إنشاء رمز CSRF
    generateCSRFToken();
    
    // تسجيل الجلسة في قاعدة البيانات
    logActiveSession();
}

/**
 * تسجيل الجلسة النشطة في قاعدة البيانات
 */
function logActiveSession() {
    global $pdo;
    
    try {
        // التحقق من وجود الجدول أولاً
        if (!tableExists('active_sessions')) {
            return;
        }
        
        // حذف الجلسات القديمة للمستخدم
        $stmt = $pdo->prepare("
            DELETE FROM active_sessions 
            WHERE user_type = ? AND user_id = ?
        ");
        $stmt->execute([$_SESSION['user_type'], $_SESSION['user_id']]);
        
        // إدراج الجلسة الجديدة
        $stmt = $pdo->prepare("
            INSERT INTO active_sessions (id, user_type, user_id, ip_address, user_agent) 
            VALUES (?, ?, ?, ?, ?)
        ");
        
        $stmt->execute([
            session_id(),
            $_SESSION['user_type'],
            $_SESSION['user_id'],
            $_SESSION['ip_address'],
            $_SESSION['user_agent']
        ]);
    } catch (Exception $e) {
        error_log("Error logging active session: " . $e->getMessage());
    }
}

/**
 * تنظيف الجلسات المنتهية الصلاحية
 */
function cleanupExpiredSessions() {
    global $pdo;
    
    try {
        // التحقق من وجود الجدول أولاً
        if (!tableExists('active_sessions')) {
            return;
        }
        
        $stmt = $pdo->prepare("
            DELETE FROM active_sessions 
            WHERE last_activity < DATE_SUB(NOW(), INTERVAL 30 MINUTE)
        ");
        $stmt->execute();
    } catch (Exception $e) {
        error_log("Error cleaning up expired sessions: " . $e->getMessage());
    }
}

/**
 * تدمير الجلسة بشكل آمن
 */
function destroySecureSession() {
    global $pdo;
    
    try {
        // حذف الجلسة من قاعدة البيانات
        if (isset($_SESSION['user_type']) && isset($_SESSION['user_id']) && tableExists('active_sessions')) {
            $stmt = $pdo->prepare("
                DELETE FROM active_sessions 
                WHERE user_type = ? AND user_id = ?
            ");
            $stmt->execute([$_SESSION['user_type'], $_SESSION['user_id']]);
        }
    } catch (Exception $e) {
        error_log("Error destroying session in database: " . $e->getMessage());
    }
    
    // تنظيف متغيرات الجلسة
    $_SESSION = array();
    
    // حذف كوكيز الجلسة
    if (ini_get("session.use_cookies")) {
        $params = session_get_cookie_params();
        setcookie(session_name(), '', time() - 42000,
            $params["path"], $params["domain"],
            $params["secure"], $params["httponly"]
        );
    }
    
    // تدمير الجلسة
    session_destroy();
}

/**
 * التحقق من الأذونات
 */
function checkPermission($required_role) {
    if (!isset($_SESSION['user_type'])) {
        return false;
    }
    
    $user_role = $_SESSION['user_type'];
    
    // تحديد التسلسل الهرمي للأذونات
    $role_hierarchy = [
        'distributor' => 3,
        'teacher' => 2,
        'parent' => 1
    ];
    
    $user_level = $role_hierarchy[$user_role] ?? 0;
    $required_level = $role_hierarchy[$required_role] ?? 0;
    
    return $user_level >= $required_level;
}

/**
 * حماية من XSS
 */
function escapeOutput($string) {
    return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
}

/**
 * التحقق من صحة الرقم
 */
function validateNumber($number, $min = null, $max = null) {
    if (!is_numeric($number)) {
        return false;
    }
    
    if ($min !== null && $number < $min) {
        return false;
    }
    
    if ($max !== null && $number > $max) {
        return false;
    }
    
    return true;
}

/**
 * التحقق من صحة التاريخ
 */
function validateDate($date, $format = 'Y-m-d') {
    $d = DateTime::createFromFormat($format, $date);
    return $d && $d->format($format) === $date;
}

/**
 * التحقق من وجود جدول في قاعدة البيانات
 */
function tableExists($table_name) {
    global $pdo;
    
    try {
        $stmt = $pdo->prepare("SHOW TABLES LIKE ?");
        $stmt->execute([$table_name]);
        return $stmt->rowCount() > 0;
    } catch (Exception $e) {
        error_log("Error checking table existence: " . $e->getMessage());
        return false;
    }
}

/**
 * تسجيل أخطاء الأمان
 */
function logSecurityError($message) {
    $log_message = "[" . date('Y-m-d H:i:s') . "] Security Error: " . $message;
    error_log($log_message);
}

/**
 * إنشاء رمز إعادة تعيين كلمة المرور
 */
function generatePasswordResetToken($email) {
    global $pdo;
    
    try {
        if (!tableExists('password_reset_tokens')) {
            return false;
        }
        
        // حذف الرموز القديمة للمستخدم
        $stmt = $pdo->prepare("DELETE FROM password_reset_tokens WHERE email = ?");
        $stmt->execute([$email]);
        
        // إنشاء رمز جديد
        $token = bin2hex(random_bytes(32));
        $expires_at = date('Y-m-d H:i:s', time() + 3600); // ساعة واحدة
        
        $stmt = $pdo->prepare("
            INSERT INTO password_reset_tokens (email, token, expires_at) 
            VALUES (?, ?, ?)
        ");
        $stmt->execute([$email, $token, $expires_at]);
        
        return $token;
    } catch (Exception $e) {
        error_log("Error generating password reset token: " . $e->getMessage());
        return false;
    }
}

/**
 * التحقق من صحة رمز إعادة تعيين كلمة المرور
 */
function validatePasswordResetToken($token) {
    global $pdo;
    
    try {
        if (!tableExists('password_reset_tokens')) {
            return false;
        }
        
        $stmt = $pdo->prepare("
            SELECT email FROM password_reset_tokens 
            WHERE token = ? AND expires_at > NOW()
        ");
        $stmt->execute([$token]);
        
        return $stmt->fetch(PDO::FETCH_COLUMN);
    } catch (Exception $e) {
        error_log("Error validating password reset token: " . $e->getMessage());
        return false;
    }
}

/**
 * حذف رمز إعادة تعيين كلمة المرور بعد الاستخدام
 */
function deletePasswordResetToken($token) {
    global $pdo;
    
    try {
        if (!tableExists('password_reset_tokens')) {
            return;
        }
        
        $stmt = $pdo->prepare("DELETE FROM password_reset_tokens WHERE token = ?");
        $stmt->execute([$token]);
    } catch (Exception $e) {
        error_log("Error deleting password reset token: " . $e->getMessage());
    }
}

// تنظيف تلقائي للبيانات القديمة (يتم تشغيله أحياناً)
// تم تقليل الاحتمال لتجنب التأثير على الأداء
if (rand(1, 1000) <= 5) { // 0.5% احتمال
    cleanupExpiredTokens();
    cleanupOldLoginAttempts();
}

