<?php
/**
 * ملف التثبيت النهائي المحسن لنظام إدارة التدريب (TD Project)
 * تم إصلاح مشكلة ترتيب تنفيذ ملفات SQL وضمان إنشاء الجداول أولاً
 */

// بدء الجلسة في بداية الملف لتجنب مشكلة Headers already sent
session_start();

// منع الوصول إذا كان النظام مثبت بالفعل
if (file_exists('includes/db.php') && file_exists('includes/.installed')) {
    die('النظام مثبت بالفعل. إذا كنت تريد إعادة التثبيت، احذف ملف includes/.installed أولاً.');
}

$step = $_GET['step'] ?? 1;
$error = '';
$success = '';

// معالجة خطوات التثبيت
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    switch ($step) {
        case 1:
            // التحقق من المتطلبات
            $step = 2;
            break;
            
        case 2:
            // اختبار الاتصال بقاعدة البيانات
            $result = testDatabaseConnection($_POST);
            if ($result['success']) {
                $_SESSION['db_config'] = $_POST;
                $step = 3;
            } else {
                $error = $result['error'];
            }
            break;
            
        case 3:
            // تنفيذ التثبيت
            if (!isset($_SESSION['db_config'])) {
                $error = 'بيانات قاعدة البيانات غير موجودة. يرجى البدء من جديد.';
                $step = 2;
            } else {
                $result = performInstallation($_SESSION['db_config']);
                if ($result['success']) {
                    $step = 4;
                    $success = 'تم تثبيت النظام بنجاح!';
                } else {
                    $error = $result['error'];
                    $step = 2;
                }
            }
            break;
    }
}

/**
 * اختبار الاتصال بقاعدة البيانات
 */
function testDatabaseConnection($config) {
    try {
        $host = $config['db_host'] ?? 'localhost';
        $port = $config['db_port'] ?? 3306;
        $dbname = $config['db_name'];
        $username = $config['db_user'];
        $password = $config['db_pass'];
        
        // التحقق من صحة البيانات المدخلة
        if (empty($dbname) || empty($username)) {
            return ['success' => false, 'error' => 'يرجى إدخال اسم قاعدة البيانات واسم المستخدم'];
        }
        
        // اختبار الاتصال بالخادم أولاً
        $dsn = "mysql:host=$host;port=$port;charset=utf8mb4";
        $pdo = new PDO($dsn, $username, $password);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        // التحقق من وجود قاعدة البيانات أو إنشاؤها
        $stmt = $pdo->prepare("CREATE DATABASE IF NOT EXISTS `$dbname` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci");
        $stmt->execute();
        
        // الاتصال بقاعدة البيانات المحددة
        $dsn = "mysql:host=$host;port=$port;dbname=$dbname;charset=utf8mb4";
        $pdo = new PDO($dsn, $username, $password);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        return ['success' => true];
        
    } catch (PDOException $e) {
        return ['success' => false, 'error' => 'خطأ في الاتصال بقاعدة البيانات: ' . $e->getMessage()];
    }
}

/**
 * تنفيذ عملية التثبيت مع ترتيب صحيح لملفات SQL
 */
function performInstallation($config) {
    try {
        $host = $config['db_host'] ?? 'localhost';
        $port = $config['db_port'] ?? 3306;
        $dbname = $config['db_name'];
        $username = $config['db_user'];
        $password = $config['db_pass'];
        $admin_email = $config['admin_email'];
        $admin_password = $config['admin_password'];
        
        // الاتصال بقاعدة البيانات
        $dsn = "mysql:host=$host;port=$port;dbname=$dbname;charset=utf8mb4";
        $pdo = new PDO($dsn, $username, $password);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        // بدء المعاملة (Transaction) لضمان التراجع في حالة الخطأ
        $pdo->beginTransaction();
        
        try {
            // الخطوة 1: إنشاء الجداول الأساسية أولاً
            createBasicTables($pdo);
            
            // الخطوة 2: إنشاء الجداول المتقدمة
            createAdvancedTables($pdo);
            
            // الخطوة 3: إدراج البيانات التجريبية
            insertSampleData($pdo);
            
            // الخطوة 4: إنشاء حساب المدير
            createAdminAccount($pdo, $admin_email, $admin_password);
            
            // تأكيد المعاملة
            $pdo->commit();
            
        } catch (Exception $e) {
            // التراجع عن المعاملة في حالة الخطأ
            $pdo->rollback();
            throw $e;
        }
        
        // إنشاء ملف إعدادات قاعدة البيانات
        $dbConfig = createDatabaseConfig($host, $port, $dbname, $username, $password);
        
        // إنشاء مجلد includes إذا لم يكن موجوداً
        if (!is_dir('includes')) {
            mkdir('includes', 0755, true);
        }
        
        // كتابة ملف إعدادات قاعدة البيانات
        file_put_contents('includes/db.php', $dbConfig);
        
        // إنشاء ملف علامة التثبيت
        $installInfo = [
            'installed_at' => date('Y-m-d H:i:s'),
            'version' => '2.0.1',
            'admin_email' => $admin_email,
            'database' => $dbname,
            'php_version' => PHP_VERSION,
            'mysql_version' => $pdo->getAttribute(PDO::ATTR_SERVER_VERSION)
        ];
        file_put_contents('includes/.installed', json_encode($installInfo, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        
        // إنشاء ملف .htaccess للأمان
        createHtaccessFile();
        
        // إنشاء المجلدات المطلوبة
        createRequiredDirectories();
        
        // إنشاء ملف سجل الأخطاء
        createErrorLogFile();
        
        return ['success' => true];
        
    } catch (Exception $e) {
        return ['success' => false, 'error' => 'خطأ في التثبيت: ' . $e->getMessage()];
    }
}

/**
 * إنشاء الجداول الأساسية
 */
function createBasicTables($pdo) {
    // جدول الموزعين (المديرين)
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `distributors` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `email` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `password` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `is_active` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `email` (`email`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول المعلمين
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `teachers` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `email` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `password` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `role` enum('admin','distributor','teacher') COLLATE utf8mb4_unicode_ci DEFAULT 'teacher',
            `subscription_type` enum('annual','semi_annual','monthly') COLLATE utf8mb4_unicode_ci DEFAULT 'annual',
            `subscription_start` date DEFAULT NULL,
            `subscription_end` date DEFAULT NULL,
            `is_active` tinyint(1) DEFAULT 1,
            `subdomain` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `custom_css` text COLLATE utf8mb4_unicode_ci,
            `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `address` text COLLATE utf8mb4_unicode_ci,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `email` (`email`),
            UNIQUE KEY `subdomain` (`subdomain`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول المواد الدراسية
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `subjects` (
            `subject_id` int(11) NOT NULL AUTO_INCREMENT,
            `subject_name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `teacher_id` int(11) DEFAULT NULL,
            `description` text COLLATE utf8mb4_unicode_ci,
            `is_active` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`subject_id`),
            KEY `teacher_id` (`teacher_id`),
            CONSTRAINT `subjects_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول المجموعات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `groups` (
            `group_id` int(11) NOT NULL AUTO_INCREMENT,
            `group_name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
            `teacher_id` int(11) DEFAULT NULL,
            `subject_id` int(11) DEFAULT NULL,
            `max_students` int(11) DEFAULT 30,
            `schedule_time` time DEFAULT NULL,
            `schedule_days` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `is_active` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`group_id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `subject_id` (`subject_id`),
            CONSTRAINT `groups_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL,
            CONSTRAINT `groups_ibfk_2` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول أولياء الأمور
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `parents` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
            `email` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
            `password` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
            `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `address` text COLLATE utf8mb4_unicode_ci,
            `national_id` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `job` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `is_active` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `email` (`email`),
            KEY `phone` (`phone`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الطلاب
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `students` (
            `student_id` int(11) NOT NULL AUTO_INCREMENT,
            `name` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `grade_level` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `phone` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `parent_code` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `payment_status` enum('paid','unpaid','partial') COLLATE utf8mb4_unicode_ci DEFAULT 'unpaid',
            `group_id` int(11) DEFAULT NULL,
            `teacher_id` int(11) DEFAULT NULL,
            `parent_id` int(11) DEFAULT NULL,
            `address` text COLLATE utf8mb4_unicode_ci,
            `birth_date` date DEFAULT NULL,
            `enrollment_date` date DEFAULT CURRENT_DATE,
            `is_active` tinyint(1) DEFAULT 1,
            `notes` text COLLATE utf8mb4_unicode_ci,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`student_id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `group_id` (`group_id`),
            KEY `parent_id` (`parent_id`),
            CONSTRAINT `students_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE SET NULL,
            CONSTRAINT `students_ibfk_2` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL,
            CONSTRAINT `students_ibfk_3` FOREIGN KEY (`parent_id`) REFERENCES `parents` (`id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الحضور
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `attendance` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `student_id` int(11) NOT NULL,
            `teacher_id` int(11) NOT NULL,
            `date` date NOT NULL,
            `status` enum('present','absent','late','excused') COLLATE utf8mb4_unicode_ci DEFAULT 'present',
            `notes` text COLLATE utf8mb4_unicode_ci,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `unique_attendance` (`student_id`,`date`),
            KEY `teacher_id` (`teacher_id`),
            KEY `date` (`date`),
            CONSTRAINT `attendance_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
            CONSTRAINT `attendance_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول المدفوعات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `payments` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `student_id` int(11) NOT NULL,
            `teacher_id` int(11) NOT NULL,
            `amount` decimal(10,2) NOT NULL,
            `due_amount` decimal(10,2) DEFAULT 0.00,
            `payment_date` date DEFAULT CURRENT_DATE,
            `payment_method` enum('cash','bank_transfer','online','check') COLLATE utf8mb4_unicode_ci DEFAULT 'cash',
            `payment_type` enum('monthly','semester','annual','registration') COLLATE utf8mb4_unicode_ci DEFAULT 'monthly',
            `status` enum('paid','pending','overdue','cancelled') COLLATE utf8mb4_unicode_ci DEFAULT 'paid',
            `notes` text COLLATE utf8mb4_unicode_ci,
            `receipt_number` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `student_id` (`student_id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `payment_date` (`payment_date`),
            CONSTRAINT `payments_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
            CONSTRAINT `payments_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");
}

/**
 * إنشاء الجداول المتقدمة
 */
function createAdvancedTables($pdo) {
    // جدول ربط الطلاب بأولياء الأمور
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `student_parent` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `student_id` int(11) NOT NULL,
            `parent_id` int(11) NOT NULL,
            `relationship` enum('father','mother','guardian','uncle','aunt','grandfather','grandmother','other') COLLATE utf8mb4_unicode_ci DEFAULT 'father',
            `is_primary` tinyint(1) DEFAULT 0,
            `can_receive_reports` tinyint(1) DEFAULT 1,
            `can_pay_fees` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `unique_student_parent` (`student_id`,`parent_id`),
            KEY `parent_id` (`parent_id`),
            CONSTRAINT `student_parent_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
            CONSTRAINT `student_parent_ibfk_2` FOREIGN KEY (`parent_id`) REFERENCES `parents` (`id`) ON DELETE CASCADE
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول التقييمات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `evaluations` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `student_id` int(11) NOT NULL,
            `teacher_id` int(11) NOT NULL,
            `subject_id` int(11) DEFAULT NULL,
            `evaluation_type` enum('quiz','exam','homework','participation','project','oral','practical') COLLATE utf8mb4_unicode_ci NOT NULL,
            `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
            `score` decimal(5,2) DEFAULT NULL,
            `max_score` decimal(5,2) DEFAULT 100.00,
            `percentage` decimal(5,2) GENERATED ALWAYS AS ((`score` / `max_score`) * 100) STORED,
            `evaluation_date` date DEFAULT (curdate()),
            `notes` text COLLATE utf8mb4_unicode_ci,
            `is_published` tinyint(1) DEFAULT 0,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `student_id` (`student_id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `subject_id` (`subject_id`),
            KEY `evaluation_date` (`evaluation_date`),
            CONSTRAINT `evaluations_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
            CONSTRAINT `evaluations_ibfk_2` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
            CONSTRAINT `evaluations_ibfk_3` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الواجبات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `assignments` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `teacher_id` int(11) NOT NULL,
            `subject_id` int(11) DEFAULT NULL,
            `group_id` int(11) DEFAULT NULL,
            `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
            `description` text COLLATE utf8mb4_unicode_ci,
            `instructions` text COLLATE utf8mb4_unicode_ci,
            `due_date` datetime DEFAULT NULL,
            `max_score` decimal(5,2) DEFAULT 100.00,
            `is_published` tinyint(1) DEFAULT 0,
            `allow_late_submission` tinyint(1) DEFAULT 0,
            `late_penalty_percent` decimal(5,2) DEFAULT 0.00,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `updated_at` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `subject_id` (`subject_id`),
            KEY `group_id` (`group_id`),
            KEY `due_date` (`due_date`),
            CONSTRAINT `assignments_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
            CONSTRAINT `assignments_ibfk_2` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL,
            CONSTRAINT `assignments_ibfk_3` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول تسليم الواجبات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `assignment_submissions` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `assignment_id` int(11) NOT NULL,
            `student_id` int(11) NOT NULL,
            `submission_text` text COLLATE utf8mb4_unicode_ci,
            `file_path` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `submission_date` datetime DEFAULT CURRENT_TIMESTAMP,
            `status` enum('submitted','late','missing','graded') COLLATE utf8mb4_unicode_ci DEFAULT 'submitted',
            `grade` decimal(5,2) DEFAULT NULL,
            `teacher_feedback` text COLLATE utf8mb4_unicode_ci,
            `graded_at` datetime DEFAULT NULL,
            `graded_by` int(11) DEFAULT NULL,
            PRIMARY KEY (`id`),
            UNIQUE KEY `unique_assignment_student` (`assignment_id`,`student_id`),
            KEY `student_id` (`student_id`),
            KEY `graded_by` (`graded_by`),
            CONSTRAINT `assignment_submissions_ibfk_1` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
            CONSTRAINT `assignment_submissions_ibfk_2` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE CASCADE,
            CONSTRAINT `assignment_submissions_ibfk_3` FOREIGN KEY (`graded_by`) REFERENCES `teachers` (`id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الرسائل
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `parent_teacher_messages` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `sender_type` enum('teacher','parent') COLLATE utf8mb4_unicode_ci NOT NULL,
            `sender_id` int(11) NOT NULL,
            `receiver_type` enum('teacher','parent') COLLATE utf8mb4_unicode_ci NOT NULL,
            `receiver_id` int(11) NOT NULL,
            `student_id` int(11) DEFAULT NULL,
            `subject` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
            `message` text COLLATE utf8mb4_unicode_ci NOT NULL,
            `is_read` tinyint(1) DEFAULT 0,
            `is_important` tinyint(1) DEFAULT 0,
            `attachment_path` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `sent_at` datetime DEFAULT CURRENT_TIMESTAMP,
            `read_at` datetime DEFAULT NULL,
            PRIMARY KEY (`id`),
            KEY `sender_type_id` (`sender_type`,`sender_id`),
            KEY `receiver_type_id` (`receiver_type`,`receiver_id`),
            KEY `student_id` (`student_id`),
            KEY `sent_at` (`sent_at`),
            CONSTRAINT `parent_teacher_messages_ibfk_1` FOREIGN KEY (`student_id`) REFERENCES `students` (`student_id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الإشعارات
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `notifications` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `user_type` enum('teacher','parent','student') COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_id` int(11) NOT NULL,
            `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
            `message` text COLLATE utf8mb4_unicode_ci NOT NULL,
            `type` enum('info','warning','success','error','reminder') COLLATE utf8mb4_unicode_ci DEFAULT 'info',
            `is_read` tinyint(1) DEFAULT 0,
            `action_url` varchar(500) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `expires_at` datetime DEFAULT NULL,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `user_type_id` (`user_type`,`user_id`),
            KEY `is_read` (`is_read`),
            KEY `created_at` (`created_at`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جدول الجدول الزمني
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `schedule` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `teacher_id` int(11) NOT NULL,
            `group_id` int(11) DEFAULT NULL,
            `subject_id` int(11) DEFAULT NULL,
            `day_of_week` enum('sunday','monday','tuesday','wednesday','thursday','friday','saturday') COLLATE utf8mb4_unicode_ci NOT NULL,
            `start_time` time NOT NULL,
            `end_time` time NOT NULL,
            `room` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
            `notes` text COLLATE utf8mb4_unicode_ci,
            `is_active` tinyint(1) DEFAULT 1,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `teacher_id` (`teacher_id`),
            KEY `group_id` (`group_id`),
            KEY `subject_id` (`subject_id`),
            KEY `day_time` (`day_of_week`,`start_time`),
            CONSTRAINT `schedule_ibfk_1` FOREIGN KEY (`teacher_id`) REFERENCES `teachers` (`id`) ON DELETE CASCADE,
            CONSTRAINT `schedule_ibfk_2` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`) ON DELETE SET NULL,
            CONSTRAINT `schedule_ibfk_3` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`subject_id`) ON DELETE SET NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    // جداول أمنية إضافية
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `login_attempts` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `email` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
            `ip_address` varchar(45) COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_agent` text COLLATE utf8mb4_unicode_ci,
            `attempt_time` datetime DEFAULT CURRENT_TIMESTAMP,
            `success` tinyint(1) DEFAULT 0,
            PRIMARY KEY (`id`),
            KEY `email_time` (`email`,`attempt_time`),
            KEY `ip_time` (`ip_address`,`attempt_time`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `active_sessions` (
            `id` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_type` enum('teacher','parent','distributor') COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_id` int(11) NOT NULL,
            `ip_address` varchar(45) COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_agent` text COLLATE utf8mb4_unicode_ci,
            `last_activity` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            KEY `user_type_id` (`user_type`,`user_id`),
            KEY `last_activity` (`last_activity`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");

    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `csrf_tokens` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `token` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_type` enum('teacher','parent','distributor') COLLATE utf8mb4_unicode_ci NOT NULL,
            `user_id` int(11) NOT NULL,
            `expires_at` datetime NOT NULL,
            `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`),
            UNIQUE KEY `token` (`token`),
            KEY `user_type_id` (`user_type`,`user_id`),
            KEY `expires_at` (`expires_at`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
    ");
}

/**
 * إدراج البيانات التجريبية
 */
function insertSampleData($pdo) {
    // إدراج معلم تجريبي
    $pdo->exec("
        INSERT IGNORE INTO `teachers` (`name`, `email`, `password`, `role`, `subscription_type`, `subscription_start`, `subscription_end`, `is_active`, `phone`) VALUES
        ('أحمد محمد المعلم', 'teacher@example.com', '$2y$10\$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'teacher', 'annual', '2024-01-01', '2024-12-31', 1, '01234567890'),
        ('فاطمة علي المعلمة', 'teacher2@example.com', '$2y$10\$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'teacher', 'annual', '2024-01-01', '2024-12-31', 1, '01234567891')
    ");

    // إدراج المواد الدراسية
    $pdo->exec("
        INSERT IGNORE INTO `subjects` (`subject_name`, `teacher_id`, `description`) VALUES
        ('الرياضيات', 1, 'مادة الرياضيات للمرحلة الثانوية'),
        ('الفيزياء', 1, 'مادة الفيزياء للمرحلة الثانوية'),
        ('الكيمياء', 2, 'مادة الكيمياء للمرحلة الثانوية'),
        ('اللغة العربية', 2, 'مادة اللغة العربية')
    ");

    // إدراج المجموعات
    $pdo->exec("
        INSERT IGNORE INTO `groups` (`group_name`, `teacher_id`, `subject_id`, `max_students`, `schedule_time`, `schedule_days`) VALUES
        ('مجموعة الرياضيات أ', 1, 1, 25, '10:00:00', 'السبت,الاثنين,الأربعاء'),
        ('مجموعة الفيزياء أ', 1, 2, 20, '14:00:00', 'الأحد,الثلاثاء,الخميس'),
        ('مجموعة الكيمياء أ', 2, 3, 30, '16:00:00', 'السبت,الاثنين'),
        ('مجموعة اللغة العربية أ', 2, 4, 35, '09:00:00', 'الأحد,الثلاثاء,الخميس')
    ");

    // إدراج أولياء أمور تجريبيين
    $pdo->exec("
        INSERT IGNORE INTO `parents` (`name`, `email`, `password`, `phone`, `address`, `national_id`, `job`) VALUES
        ('أحمد محمد علي الأب', 'ahmed.parent@example.com', '$2y$10\$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567890', 'القاهرة، مصر', '12345678901234', 'مهندس'),
        ('فاطمة أحمد الأم', 'fatima.parent@example.com', '$2y$10\$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', '01234567891', 'الإسكندرية، مصر', '12345678901235', 'طبيبة')
    ");

    // إدراج طلاب تجريبيين
    $pdo->exec("
        INSERT IGNORE INTO `students` (`name`, `grade_level`, `phone`, `parent_code`, `payment_status`, `group_id`, `teacher_id`, `parent_id`, `address`, `enrollment_date`) VALUES
        ('محمد أحمد علي', 'الثالث الثانوي', '01111111111', 'PAR001', 'paid', 1, 1, 1, 'القاهرة، مصر', '2024-01-15'),
        ('سارة محمد حسن', 'الثالث الثانوي', '01222222222', 'PAR002', 'paid', 1, 1, 2, 'الجيزة، مصر', '2024-01-16')
    ");
}

/**
 * إنشاء حساب المدير
 */
function createAdminAccount($pdo, $admin_email, $admin_password) {
    $hashedPassword = password_hash($admin_password, PASSWORD_DEFAULT);
    $stmt = $pdo->prepare("
        INSERT INTO distributors (name, email, password, phone, is_active) 
        VALUES (?, ?, ?, ?, 1)
        ON DUPLICATE KEY UPDATE 
        password = VALUES(password), 
        name = VALUES(name),
        is_active = 1
    ");
    $stmt->execute(['مدير النظام', $admin_email, $hashedPassword, '']);
}

/**
 * إنشاء ملف إعدادات قاعدة البيانات
 */
function createDatabaseConfig($host, $port, $dbname, $username, $password) {
    return "<?php
/**
 * إعدادات قاعدة البيانات
 * تم إنشاؤها تلقائياً بواسطة ملف التثبيت المحسن
 * تاريخ الإنشاء: " . date('Y-m-d H:i:s') . "
 */

\$host = '$host';
\$port = '$port';
\$dbname = '$dbname';
\$username = '$username';
\$password = '$password';

try {
    \$pdo = new PDO(\"mysql:host=\$host;port=\$port;dbname=\$dbname;charset=utf8mb4\", \$username, \$password);
    \$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    \$pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
    \$pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
} catch (PDOException \$e) {
    error_log('Database connection error: ' . \$e->getMessage());
    die('خطأ في الاتصال بقاعدة البيانات. يرجى التحقق من إعدادات الخادم.');
}

// تعريف ثوابت النظام
define('DB_HOST', \$host);
define('DB_PORT', \$port);
define('DB_NAME', \$dbname);
define('DB_USER', \$username);
define('DB_PASS', \$password);
define('SITE_URL', 'http' . (isset(\$_SERVER['HTTPS']) ? 's' : '') . '://' . \$_SERVER['HTTP_HOST'] . dirname(\$_SERVER['SCRIPT_NAME']));
define('UPLOAD_PATH', __DIR__ . '/../uploads/');
define('CACHE_PATH', __DIR__ . '/../cache/');
define('LOG_PATH', __DIR__ . '/../logs/');

// إنشاء المجلدات المطلوبة
\$directories = [UPLOAD_PATH, CACHE_PATH, LOG_PATH];
foreach (\$directories as \$dir) {
    if (!is_dir(\$dir)) {
        mkdir(\$dir, 0755, true);
    }
}

// دالة مساعدة لتسجيل الأخطاء
function logError(\$message, \$file = 'error.log') {
    \$logFile = LOG_PATH . \$file;
    \$timestamp = date('Y-m-d H:i:s');
    \$logMessage = \"[\$timestamp] \$message\" . PHP_EOL;
    file_put_contents(\$logFile, \$logMessage, FILE_APPEND | LOCK_EX);
}

// دالة مساعدة للتحقق من صحة البيانات
function sanitizeInput(\$input) {
    return htmlspecialchars(strip_tags(trim(\$input)), ENT_QUOTES, 'UTF-8');
}
?>";
}

/**
 * إنشاء ملف .htaccess للأمان
 */
function createHtaccessFile() {
    $htaccess = "# حماية الملفات الحساسة
<Files \"*.sql\">
    Order allow,deny
    Deny from all
</Files>

<Files \"*.md\">
    Order allow,deny
    Deny from all
</Files>

<Files \".installed\">
    Order allow,deny
    Deny from all
</Files>

<Files \"install*.php\">
    Order allow,deny
    Deny from all
</Files>

<Files \"debug*.php\">
    Order allow,deny
    Deny from all
</Files>

<Files \"*.log\">
    Order allow,deny
    Deny from all
</Files>

# حماية مجلد includes
<Directory \"includes\">
    Order allow,deny
    Deny from all
</Directory>

# حماية مجلد logs
<Directory \"logs\">
    Order allow,deny
    Deny from all
</Directory>

# إعادة كتابة URLs
RewriteEngine On

# منع الوصول المباشر للملفات الحساسة
RewriteRule ^(includes|logs|cache|backups)/ - [F,L]

# تفعيل الضغط
<IfModule mod_deflate.c>
    AddOutputFilterByType DEFLATE text/plain
    AddOutputFilterByType DEFLATE text/html
    AddOutputFilterByType DEFLATE text/xml
    AddOutputFilterByType DEFLATE text/css
    AddOutputFilterByType DEFLATE application/xml
    AddOutputFilterByType DEFLATE application/xhtml+xml
    AddOutputFilterByType DEFLATE application/rss+xml
    AddOutputFilterByType DEFLATE application/javascript
    AddOutputFilterByType DEFLATE application/x-javascript
</IfModule>

# تعيين رؤوس التخزين المؤقت
<IfModule mod_expires.c>
    ExpiresActive on
    ExpiresByType text/css \"access plus 1 year\"
    ExpiresByType application/javascript \"access plus 1 year\"
    ExpiresByType image/png \"access plus 1 year\"
    ExpiresByType image/jpg \"access plus 1 year\"
    ExpiresByType image/jpeg \"access plus 1 year\"
    ExpiresByType image/gif \"access plus 1 year\"
</IfModule>

# رؤوس الأمان
<IfModule mod_headers.c>
    Header always set X-Frame-Options DENY
    Header always set X-Content-Type-Options nosniff
    Header always set X-XSS-Protection \"1; mode=block\"
    Header always set Referrer-Policy \"strict-origin-when-cross-origin\"
</IfModule>";

    file_put_contents('.htaccess', $htaccess);
}

/**
 * إنشاء المجلدات المطلوبة
 */
function createRequiredDirectories() {
    $directories = [
        'uploads' => 0755,
        'uploads/profiles' => 0755,
        'cache' => 0755,
        'logs' => 0755,
        'backups' => 0755
    ];
    
    foreach ($directories as $dir => $permissions) {
        if (!is_dir($dir)) {
            mkdir($dir, $permissions, true);
        }
    }
}

/**
 * إنشاء ملف سجل الأخطاء
 */
function createErrorLogFile() {
    $logContent = "# سجل أخطاء نظام إدارة التدريب
# تم الإنشاء في: " . date('Y-m-d H:i:s') . "
# ==========================================

";
    
    if (!file_exists('logs/error.log')) {
        file_put_contents('logs/error.log', $logContent);
    }
}

/**
 * التحقق من المتطلبات
 */
function checkRequirements() {
    $requirements = [
        'PHP Version >= 7.4' => version_compare(PHP_VERSION, '7.4.0', '>='),
        'PDO Extension' => extension_loaded('pdo'),
        'PDO MySQL Extension' => extension_loaded('pdo_mysql'),
        'GD Extension' => extension_loaded('gd'),
        'cURL Extension' => extension_loaded('curl'),
        'mbstring Extension' => extension_loaded('mbstring'),
        'JSON Extension' => extension_loaded('json'),
        'OpenSSL Extension' => extension_loaded('openssl'),
        'Directory Writable' => is_writable('.'),
        'Memory Limit >= 128M' => (int)ini_get('memory_limit') >= 128,
    ];
    
    return $requirements;
}

/**
 * التحقق من قوة كلمة المرور
 */
function validatePassword($password) {
    $errors = [];
    
    if (strlen($password) < 8) {
        $errors[] = 'كلمة المرور يجب أن تكون 8 أحرف على الأقل';
    }
    
    if (!preg_match('/[A-Z]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على حرف كبير واحد على الأقل';
    }
    
    if (!preg_match('/[a-z]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على حرف صغير واحد على الأقل';
    }
    
    if (!preg_match('/[0-9]/', $password)) {
        $errors[] = 'كلمة المرور يجب أن تحتوي على رقم واحد على الأقل';
    }
    
    return $errors;
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تثبيت نظام إدارة التدريب - النسخة النهائية المحسنة</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        body {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        .install-container {
            max-width: 900px;
            margin: 30px auto;
            background: white;
            border-radius: 15px;
            box-shadow: 0 20px 40px rgba(0,0,0,0.1);
            overflow: hidden;
        }
        .install-header {
            background: linear-gradient(135deg, #2c3e50 0%, #34495e 100%);
            color: white;
            padding: 30px;
            text-align: center;
        }
        .install-body {
            padding: 40px;
        }
        .step-indicator {
            display: flex;
            justify-content: center;
            margin-bottom: 30px;
        }
        .step {
            width: 50px;
            height: 50px;
            border-radius: 50%;
            background: #e9ecef;
            display: flex;
            align-items: center;
            justify-content: center;
            margin: 0 15px;
            font-weight: bold;
            position: relative;
            transition: all 0.3s ease;
        }
        .step.active {
            background: #007bff;
            color: white;
            transform: scale(1.1);
        }
        .step.completed {
            background: #28a745;
            color: white;
        }
        .step::after {
            content: '';
            position: absolute;
            top: 50%;
            right: -25px;
            width: 30px;
            height: 3px;
            background: #e9ecef;
            transform: translateY(-50%);
        }
        .step:last-child::after {
            display: none;
        }
        .step.completed::after {
            background: #28a745;
        }
        .requirement-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 15px 0;
            border-bottom: 1px solid #eee;
        }
        .requirement-item:last-child {
            border-bottom: none;
        }
        .status-ok {
            color: #28a745;
            font-weight: bold;
        }
        .status-error {
            color: #dc3545;
            font-weight: bold;
        }
        .form-floating label {
            right: 12px;
            left: auto;
        }
        .btn-install {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            border: none;
            padding: 15px 40px;
            border-radius: 25px;
            color: white;
            font-weight: bold;
            transition: all 0.3s ease;
        }
        .btn-install:hover {
            transform: translateY(-3px);
            box-shadow: 0 10px 20px rgba(0,0,0,0.2);
            color: white;
        }
        .progress-bar-custom {
            height: 8px;
            border-radius: 10px;
            background: #e9ecef;
            margin: 20px 0;
        }
        .progress-fill {
            height: 100%;
            border-radius: 10px;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            transition: width 0.5s ease;
        }
        .alert-custom {
            border-radius: 10px;
            border: none;
            padding: 20px;
        }
    </style>
</head>
<body>

<div class="install-container">
    <div class="install-header">
        <h1><i class="fas fa-cogs me-3"></i>تثبيت نظام إدارة التدريب</h1>
        <p class="mb-0">النسخة النهائية المحسنة - مع إصلاح مشاكل SQL</p>
        <div class="progress-bar-custom">
            <div class="progress-fill" style="width: <?= ($step * 25) ?>%"></div>
        </div>
    </div>
    
    <div class="install-body">
        <!-- مؤشر الخطوات -->
        <div class="step-indicator">
            <div class="step <?= $step >= 1 ? ($step > 1 ? 'completed' : 'active') : '' ?>">
                <i class="fas fa-<?= $step > 1 ? 'check' : 'clipboard-check' ?>"></i>
            </div>
            <div class="step <?= $step >= 2 ? ($step > 2 ? 'completed' : 'active') : '' ?>">
                <i class="fas fa-<?= $step > 2 ? 'check' : 'database' ?>"></i>
            </div>
            <div class="step <?= $step >= 3 ? ($step > 3 ? 'completed' : 'active') : '' ?>">
                <i class="fas fa-<?= $step > 3 ? 'check' : 'cog' ?>"></i>
            </div>
            <div class="step <?= $step >= 4 ? 'active' : '' ?>">
                <i class="fas fa-flag-checkered"></i>
            </div>
        </div>

        <?php if ($error): ?>
            <div class="alert alert-danger alert-custom">
                <i class="fas fa-exclamation-circle me-2"></i>
                <strong>خطأ:</strong> <?= htmlspecialchars($error) ?>
            </div>
        <?php endif; ?>

        <?php if ($success): ?>
            <div class="alert alert-success alert-custom">
                <i class="fas fa-check-circle me-2"></i>
                <strong>نجح:</strong> <?= htmlspecialchars($success) ?>
            </div>
        <?php endif; ?>

        <?php if ($step == 1): ?>
            <!-- الخطوة 1: التحقق من المتطلبات -->
            <div class="text-center mb-4">
                <h3><i class="fas fa-clipboard-check me-2"></i>التحقق من المتطلبات</h3>
                <p class="text-muted">نتحقق من توفر جميع المتطلبات اللازمة لتشغيل النظام</p>
            </div>

            <div class="requirements-list">
                <?php 
                $requirements = checkRequirements();
                $allPassed = true;
                foreach ($requirements as $requirement => $status): 
                    if (!$status) $allPassed = false;
                ?>
                    <div class="requirement-item">
                        <span><i class="fas fa-<?= $status ? 'check-circle' : 'times-circle' ?> me-2"></i><?= $requirement ?></span>
                        <span class="<?= $status ? 'status-ok' : 'status-error' ?>">
                            <?= $status ? 'متوفر' : 'غير متوفر' ?>
                        </span>
                    </div>
                <?php endforeach; ?>
            </div>

            <?php if ($allPassed): ?>
                <div class="text-center mt-4">
                    <form method="post" action="?step=2">
                        <button type="submit" class="btn btn-install btn-lg">
                            <i class="fas fa-arrow-left me-2"></i>متابعة إلى الخطوة التالية
                        </button>
                    </form>
                </div>
            <?php else: ?>
                <div class="alert alert-warning alert-custom mt-4">
                    <i class="fas fa-exclamation-triangle me-2"></i>
                    <strong>تحذير:</strong> يرجى التأكد من توفر جميع المتطلبات قبل المتابعة. قد يؤثر عدم توفرها على عمل النظام.
                </div>
                <div class="text-center mt-3">
                    <form method="post" action="?step=2">
                        <button type="submit" class="btn btn-warning btn-lg">
                            <i class="fas fa-arrow-left me-2"></i>متابعة رغم التحذيرات
                        </button>
                    </form>
                </div>
            <?php endif; ?>

        <?php elseif ($step == 2): ?>
            <!-- الخطوة 2: إعدادات قاعدة البيانات -->
            <div class="text-center mb-4">
                <h3><i class="fas fa-database me-2"></i>إعدادات قاعدة البيانات</h3>
                <p class="text-muted">أدخل بيانات الاتصال بقاعدة البيانات وحساب المدير</p>
            </div>

            <form method="post" action="?step=2" id="dbForm">
                <div class="row">
                    <div class="col-md-8 mb-3">
                        <div class="form-floating">
                            <input type="text" class="form-control" id="db_host" name="db_host" 
                                   value="<?= $_POST['db_host'] ?? 'localhost' ?>" required>
                            <label for="db_host">خادم قاعدة البيانات</label>
                        </div>
                    </div>
                    <div class="col-md-4 mb-3">
                        <div class="form-floating">
                            <input type="number" class="form-control" id="db_port" name="db_port" 
                                   value="<?= $_POST['db_port'] ?? '3306' ?>" required>
                            <label for="db_port">المنفذ</label>
                        </div>
                    </div>
                </div>

                <div class="mb-3">
                    <div class="form-floating">
                        <input type="text" class="form-control" id="db_name" name="db_name" 
                               value="<?= $_POST['db_name'] ?? '' ?>" required>
                        <label for="db_name">اسم قاعدة البيانات</label>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6 mb-3">
                        <div class="form-floating">
                            <input type="text" class="form-control" id="db_user" name="db_user" 
                                   value="<?= $_POST['db_user'] ?? '' ?>" required>
                            <label for="db_user">اسم المستخدم</label>
                        </div>
                    </div>
                    <div class="col-md-6 mb-3">
                        <div class="form-floating">
                            <input type="password" class="form-control" id="db_pass" name="db_pass" 
                                   value="<?= $_POST['db_pass'] ?? '' ?>">
                            <label for="db_pass">كلمة المرور</label>
                        </div>
                    </div>
                </div>

                <hr class="my-4">

                <div class="text-center mb-3">
                    <h5><i class="fas fa-user-shield me-2"></i>حساب المدير الرئيسي</h5>
                    <p class="text-muted">سيتم إنشاء حساب المدير الرئيسي للنظام</p>
                </div>

                <div class="row">
                    <div class="col-md-6 mb-3">
                        <div class="form-floating">
                            <input type="email" class="form-control" id="admin_email" name="admin_email" 
                                   value="<?= $_POST['admin_email'] ?? '' ?>" required>
                            <label for="admin_email">البريد الإلكتروني للمدير</label>
                        </div>
                    </div>
                    <div class="col-md-6 mb-3">
                        <div class="form-floating">
                            <input type="password" class="form-control" id="admin_password" name="admin_password" 
                                   minlength="8" required>
                            <label for="admin_password">كلمة مرور المدير</label>
                        </div>
                        <div class="form-text">يجب أن تحتوي على 8 أحرف على الأقل مع أحرف كبيرة وصغيرة وأرقام</div>
                    </div>
                </div>

                <div class="text-center mt-4">
                    <button type="submit" class="btn btn-install btn-lg">
                        <i class="fas fa-plug me-2"></i>اختبار الاتصال والمتابعة
                    </button>
                </div>
            </form>

        <?php elseif ($step == 3): ?>
            <!-- الخطوة 3: تأكيد التثبيت -->
            <div class="text-center mb-4">
                <h3><i class="fas fa-check-double me-2"></i>تأكيد التثبيت</h3>
                <p class="text-muted">تم اختبار الاتصال بنجاح. اضغط لبدء عملية التثبيت</p>
            </div>

            <div class="alert alert-info alert-custom">
                <h5><i class="fas fa-info-circle me-2"></i>ملخص الإعدادات:</h5>
                <ul class="mb-0">
                    <li><strong>خادم قاعدة البيانات:</strong> <?= htmlspecialchars($_SESSION['db_config']['db_host']) ?>:<?= htmlspecialchars($_SESSION['db_config']['db_port']) ?></li>
                    <li><strong>قاعدة البيانات:</strong> <?= htmlspecialchars($_SESSION['db_config']['db_name']) ?></li>
                    <li><strong>المستخدم:</strong> <?= htmlspecialchars($_SESSION['db_config']['db_user']) ?></li>
                    <li><strong>البريد الإلكتروني للمدير:</strong> <?= htmlspecialchars($_SESSION['db_config']['admin_email']) ?></li>
                </ul>
            </div>

            <div class="alert alert-warning alert-custom">
                <i class="fas fa-exclamation-triangle me-2"></i>
                <strong>تحذير:</strong> سيتم إنشاء الجداول وإدراج البيانات الأساسية. تأكد من صحة الإعدادات قبل المتابعة.
                <br><small>في حالة حدوث خطأ، سيتم التراجع عن جميع التغييرات تلقائياً.</small>
            </div>

            <div class="text-center">
                <form method="post" action="?step=3">
                    <button type="submit" class="btn btn-install btn-lg">
                        <i class="fas fa-rocket me-2"></i>بدء التثبيت الآن
                    </button>
                </form>
            </div>

        <?php elseif ($step == 4): ?>
            <!-- الخطوة 4: اكتمال التثبيت -->
            <div class="text-center">
                <div class="mb-4">
                    <i class="fas fa-check-circle text-success" style="font-size: 5rem;"></i>
                </div>
                
                <h3 class="text-success mb-3">تم التثبيت بنجاح!</h3>
                <p class="text-muted mb-4">تم تثبيت نظام إدارة التدريب بنجاح وهو جاهز للاستخدام الآن</p>

                <div class="alert alert-success alert-custom text-start">
                    <h5><i class="fas fa-info-circle me-2"></i>تم إنجاز المهام التالية:</h5>
                    <ul class="mb-0">
                        <li>✅ إنشاء جميع الجداول المطلوبة</li>
                        <li>✅ إدراج البيانات الأساسية</li>
                        <li>✅ إنشاء حساب المدير</li>
                        <li>✅ إعداد ملفات الأمان</li>
                        <li>✅ إنشاء المجلدات المطلوبة</li>
                    </ul>
                </div>

                <div class="alert alert-warning alert-custom text-start">
                    <h5><i class="fas fa-shield-alt me-2"></i>خطوات مهمة بعد التثبيت:</h5>
                    <ol class="mb-0">
                        <li><strong>احذف ملف التثبيت:</strong> احذف هذا الملف فوراً لأسباب أمنية</li>
                        <li><strong>غير كلمة المرور:</strong> غير كلمة مرور المدير من لوحة التحكم</li>
                        <li><strong>راجع الإعدادات:</strong> تحقق من جميع إعدادات النظام</li>
                        <li><strong>النسخ الاحتياطية:</strong> فعل النسخ الاحتياطية التلقائية</li>
                    </ol>
                </div>

                <div class="mt-4">
                    <a href="admin/login.php" class="btn btn-success btn-lg me-3">
                        <i class="fas fa-sign-in-alt me-2"></i>تسجيل الدخول للوحة التحكم
                    </a>
                    <a href="index.php" class="btn btn-outline-primary btn-lg">
                        <i class="fas fa-home me-2"></i>الذهاب للصفحة الرئيسية
                    </a>
                </div>
            </div>
        <?php endif; ?>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>

