<?php
/**
 * أداة صيانة نظام إدارة التدريب
 * تتضمن أدوات للنسخ الاحتياطي والتنظيف والإصلاح
 */

// التحقق من الصلاحيات
session_start();
if (!isset($_SESSION['user_type']) || $_SESSION['user_type'] !== 'admin') {
    die('غير مسموح بالوصول. هذه الأداة للمديرين فقط.');
}

require_once 'includes/db.php';

class SystemMaintenance {
    
    private $pdo;
    private $logFile;
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
        $this->logFile = __DIR__ . '/logs/maintenance.log';
        
        // إنشاء مجلد logs إذا لم يكن موجوداً
        if (!is_dir(dirname($this->logFile))) {
            mkdir(dirname($this->logFile), 0755, true);
        }
    }
    
    /**
     * إنشاء نسخة احتياطية من قاعدة البيانات
     */
    public function createDatabaseBackup() {
        try {
            $backupDir = __DIR__ . '/backups';
            if (!is_dir($backupDir)) {
                mkdir($backupDir, 0755, true);
            }
            
            $timestamp = date('Y-m-d_H-i-s');
            $backupFile = "$backupDir/backup_$timestamp.sql";
            
            // الحصول على اسم قاعدة البيانات
            $dbName = DB_NAME;
            
            // تنفيذ أمر mysqldump
            $command = "mysqldump -h " . DB_HOST . " -u " . DB_USER . " -p" . DB_PASS . " $dbName > $backupFile";
            
            exec($command, $output, $returnCode);
            
            if ($returnCode === 0 && file_exists($backupFile)) {
                $fileSize = filesize($backupFile);
                $this->log("تم إنشاء نسخة احتياطية بنجاح: $backupFile (الحجم: " . $this->formatBytes($fileSize) . ")");
                
                // تسجيل في قاعدة البيانات
                $stmt = $this->pdo->prepare("
                    INSERT INTO backup_log (backup_type, backup_path, file_size, status, completed_at) 
                    VALUES ('full', ?, ?, 'completed', NOW())
                ");
                $stmt->execute([$backupFile, $fileSize]);
                
                return ['success' => true, 'file' => $backupFile, 'size' => $fileSize];
            } else {
                throw new Exception('فشل في إنشاء النسخة الاحتياطية');
            }
            
        } catch (Exception $e) {
            $this->log("خطأ في إنشاء النسخة الاحتياطية: " . $e->getMessage());
            return ['success' => false, 'error' => $e->getMessage()];
        }
    }
    
    /**
     * تنظيف البيانات القديمة
     */
    public function cleanupOldData($days = 90) {
        try {
            $deletedRecords = 0;
            
            // حذف سجلات النشاط القديمة
            $stmt = $this->pdo->prepare("DELETE FROM user_activity_log WHERE created_at < DATE_SUB(NOW(), INTERVAL ? DAY)");
            $stmt->execute([$days]);
            $deletedRecords += $stmt->rowCount();
            
            // حذف محاولات تسجيل الدخول القديمة
            $stmt = $this->pdo->prepare("DELETE FROM login_attempts WHERE attempt_time < DATE_SUB(NOW(), INTERVAL ? DAY)");
            $stmt->execute([$days]);
            $deletedRecords += $stmt->rowCount();
            
            // حذف الجلسات المنتهية الصلاحية
            $stmt = $this->pdo->prepare("DELETE FROM active_sessions WHERE last_activity < DATE_SUB(NOW(), INTERVAL 1 DAY)");
            $stmt->execute();
            $deletedRecords += $stmt->rowCount();
            
            // حذف رموز CSRF المنتهية الصلاحية
            $stmt = $this->pdo->prepare("DELETE FROM csrf_tokens WHERE expires_at < NOW()");
            $stmt->execute();
            $deletedRecords += $stmt->rowCount();
            
            // حذف الإشعارات القديمة المقروءة
            $stmt = $this->pdo->prepare("DELETE FROM notifications WHERE is_read = 1 AND created_at < DATE_SUB(NOW(), INTERVAL ? DAY)");
            $stmt->execute([$days]);
            $deletedRecords += $stmt->rowCount();
            
            $this->log("تم تنظيف $deletedRecords سجل قديم");
            
            return ['success' => true, 'deleted_records' => $deletedRecords];
            
        } catch (Exception $e) {
            $this->log("خطأ في تنظيف البيانات: " . $e->getMessage());
            return ['success' => false, 'error' => $e->getMessage()];
        }
    }
    
    /**
     * تحسين جداول قاعدة البيانات
     */
    public function optimizeTables() {
        try {
            $tables = [
                'distributors', 'teachers', 'students', 'subjects', 'groups',
                'attendance', 'payments', 'parents', 'student_parent',
                'evaluations', 'assignments', 'assignment_submissions',
                'parent_teacher_messages', 'notifications', 'schedule',
                'user_activity_log', 'active_sessions', 'login_attempts'
            ];
            
            $optimizedTables = 0;
            
            foreach ($tables as $table) {
                try {
                    $this->pdo->exec("OPTIMIZE TABLE `$table`");
                    $optimizedTables++;
                } catch (PDOException $e) {
                    $this->log("تحذير: لم يتم تحسين الجدول $table - " . $e->getMessage());
                }
            }
            
            $this->log("تم تحسين $optimizedTables جدول");
            
            return ['success' => true, 'optimized_tables' => $optimizedTables];
            
        } catch (Exception $e) {
            $this->log("خطأ في تحسين الجداول: " . $e->getMessage());
            return ['success' => false, 'error' => $e->getMessage()];
        }
    }
    
    /**
     * فحص سلامة قاعدة البيانات
     */
    public function checkDatabaseIntegrity() {
        try {
            $issues = [];
            
            // فحص الطلاب بدون معلمين
            $stmt = $this->pdo->query("SELECT COUNT(*) as count FROM students WHERE teacher_id IS NULL");
            $result = $stmt->fetch();
            if ($result['count'] > 0) {
                $issues[] = "يوجد {$result['count']} طالب بدون معلم مخصص";
            }
            
            // فحص المعلمين بدون طلاب
            $stmt = $this->pdo->query("
                SELECT COUNT(*) as count FROM teachers t 
                WHERE t.is_active = 1 AND NOT EXISTS (
                    SELECT 1 FROM students s WHERE s.teacher_id = t.id
                )
            ");
            $result = $stmt->fetch();
            if ($result['count'] > 0) {
                $issues[] = "يوجد {$result['count']} معلم نشط بدون طلاب";
            }
            
            // فحص المدفوعات المعلقة
            $stmt = $this->pdo->query("SELECT COUNT(*) as count FROM payments WHERE status = 'pending' AND payment_date < DATE_SUB(NOW(), INTERVAL 30 DAY)");
            $result = $stmt->fetch();
            if ($result['count'] > 0) {
                $issues[] = "يوجد {$result['count']} دفعة معلقة لأكثر من 30 يوم";
            }
            
            // فحص الرسائل غير المقروءة القديمة
            $stmt = $this->pdo->query("SELECT COUNT(*) as count FROM parent_teacher_messages WHERE is_read = 0 AND sent_at < DATE_SUB(NOW(), INTERVAL 7 DAY)");
            $result = $stmt->fetch();
            if ($result['count'] > 0) {
                $issues[] = "يوجد {$result['count']} رسالة غير مقروءة لأكثر من 7 أيام";
            }
            
            $this->log("تم فحص سلامة قاعدة البيانات - وُجدت " . count($issues) . " مشكلة");
            
            return ['success' => true, 'issues' => $issues];
            
        } catch (Exception $e) {
            $this->log("خطأ في فحص سلامة قاعدة البيانات: " . $e->getMessage());
            return ['success' => false, 'error' => $e->getMessage()];
        }
    }
    
    /**
     * إنشاء تقرير الأداء
     */
    public function generatePerformanceReport() {
        try {
            $report = [];
            
            // إحصائيات عامة
            $stmt = $this->pdo->query("SELECT COUNT(*) as total FROM teachers WHERE is_active = 1");
            $report['active_teachers'] = $stmt->fetch()['total'];
            
            $stmt = $this->pdo->query("SELECT COUNT(*) as total FROM students WHERE is_active = 1");
            $report['active_students'] = $stmt->fetch()['total'];
            
            $stmt = $this->pdo->query("SELECT COUNT(*) as total FROM parents WHERE is_active = 1");
            $report['active_parents'] = $stmt->fetch()['total'];
            
            // إحصائيات الحضور
            $stmt = $this->pdo->query("
                SELECT 
                    COUNT(*) as total_attendance,
                    SUM(CASE WHEN status = 'present' THEN 1 ELSE 0 END) as present_count,
                    ROUND((SUM(CASE WHEN status = 'present' THEN 1 ELSE 0 END) / COUNT(*)) * 100, 2) as attendance_rate
                FROM attendance 
                WHERE date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
            ");
            $attendanceStats = $stmt->fetch();
            $report['attendance'] = $attendanceStats;
            
            // إحصائيات المدفوعات
            $stmt = $this->pdo->query("
                SELECT 
                    COUNT(*) as total_payments,
                    SUM(amount) as total_amount,
                    SUM(due_amount) as total_due,
                    AVG(amount) as average_payment
                FROM payments 
                WHERE payment_date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY)
            ");
            $paymentStats = $stmt->fetch();
            $report['payments'] = $paymentStats;
            
            // إحصائيات الرسائل
            $stmt = $this->pdo->query("
                SELECT 
                    COUNT(*) as total_messages,
                    SUM(CASE WHEN is_read = 0 THEN 1 ELSE 0 END) as unread_messages
                FROM parent_teacher_messages 
                WHERE sent_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
            ");
            $messageStats = $stmt->fetch();
            $report['messages'] = $messageStats;
            
            // حجم قاعدة البيانات
            $stmt = $this->pdo->query("
                SELECT 
                    ROUND(SUM(data_length + index_length) / 1024 / 1024, 2) AS db_size_mb
                FROM information_schema.tables 
                WHERE table_schema = '" . DB_NAME . "'
            ");
            $report['database_size_mb'] = $stmt->fetch()['db_size_mb'];
            
            $this->log("تم إنشاء تقرير الأداء");
            
            return ['success' => true, 'report' => $report];
            
        } catch (Exception $e) {
            $this->log("خطأ في إنشاء تقرير الأداء: " . $e->getMessage());
            return ['success' => false, 'error' => $e->getMessage()];
        }
    }
    
    /**
     * تسجيل الأحداث
     */
    private function log($message) {
        $timestamp = date('Y-m-d H:i:s');
        $logMessage = "[$timestamp] $message" . PHP_EOL;
        file_put_contents($this->logFile, $logMessage, FILE_APPEND | LOCK_EX);
    }
    
    /**
     * تنسيق حجم الملف
     */
    private function formatBytes($bytes, $precision = 2) {
        $units = array('B', 'KB', 'MB', 'GB', 'TB');
        
        for ($i = 0; $bytes > 1024 && $i < count($units) - 1; $i++) {
            $bytes /= 1024;
        }
        
        return round($bytes, $precision) . ' ' . $units[$i];
    }
}

// معالجة الطلبات
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $maintenance = new SystemMaintenance($pdo);
    $action = $_POST['action'] ?? '';
    
    header('Content-Type: application/json');
    
    switch ($action) {
        case 'backup':
            echo json_encode($maintenance->createDatabaseBackup());
            break;
            
        case 'cleanup':
            $days = intval($_POST['days'] ?? 90);
            echo json_encode($maintenance->cleanupOldData($days));
            break;
            
        case 'optimize':
            echo json_encode($maintenance->optimizeTables());
            break;
            
        case 'check_integrity':
            echo json_encode($maintenance->checkDatabaseIntegrity());
            break;
            
        case 'performance_report':
            echo json_encode($maintenance->generatePerformanceReport());
            break;
            
        default:
            echo json_encode(['success' => false, 'error' => 'إجراء غير صحيح']);
    }
    exit;
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>أدوات صيانة النظام</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .maintenance-card {
            border: none;
            border-radius: 15px;
            box-shadow: 0 5px 15px rgba(0,0,0,0.1);
            transition: transform 0.2s;
        }
        .maintenance-card:hover {
            transform: translateY(-5px);
        }
        .btn-maintenance {
            border-radius: 25px;
            padding: 10px 25px;
            font-weight: bold;
        }
        .result-box {
            background: #f8f9fa;
            border-radius: 10px;
            padding: 15px;
            margin-top: 15px;
            display: none;
        }
        .loading {
            display: none;
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <div class="row">
        <div class="col-12">
            <div class="d-flex justify-content-between align-items-center mb-4">
                <h1><i class="fas fa-tools me-3"></i>أدوات صيانة النظام</h1>
                <a href="admin/dashboard.php" class="btn btn-outline-primary">
                    <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                </a>
            </div>
        </div>
    </div>
    
    <div class="row">
        <!-- النسخ الاحتياطي -->
        <div class="col-md-6 col-lg-4 mb-4">
            <div class="card maintenance-card h-100">
                <div class="card-body text-center">
                    <i class="fas fa-database fa-3x text-primary mb-3"></i>
                    <h5 class="card-title">النسخ الاحتياطي</h5>
                    <p class="card-text">إنشاء نسخة احتياطية كاملة من قاعدة البيانات</p>
                    <button class="btn btn-primary btn-maintenance" onclick="performAction('backup')">
                        <i class="fas fa-download me-2"></i>إنشاء نسخة احتياطية
                    </button>
                    <div class="loading" id="backup-loading">
                        <div class="spinner-border spinner-border-sm me-2"></div>
                        جاري الإنشاء...
                    </div>
                    <div class="result-box" id="backup-result"></div>
                </div>
            </div>
        </div>
        
        <!-- تنظيف البيانات -->
        <div class="col-md-6 col-lg-4 mb-4">
            <div class="card maintenance-card h-100">
                <div class="card-body text-center">
                    <i class="fas fa-broom fa-3x text-warning mb-3"></i>
                    <h5 class="card-title">تنظيف البيانات</h5>
                    <p class="card-text">حذف السجلات والبيانات القديمة غير المطلوبة</p>
                    <div class="mb-3">
                        <label class="form-label">الاحتفاظ بالبيانات لـ:</label>
                        <select class="form-select" id="cleanup-days">
                            <option value="30">30 يوم</option>
                            <option value="60">60 يوم</option>
                            <option value="90" selected>90 يوم</option>
                            <option value="180">180 يوم</option>
                        </select>
                    </div>
                    <button class="btn btn-warning btn-maintenance" onclick="performCleanup()">
                        <i class="fas fa-trash-alt me-2"></i>تنظيف البيانات
                    </button>
                    <div class="loading" id="cleanup-loading">
                        <div class="spinner-border spinner-border-sm me-2"></div>
                        جاري التنظيف...
                    </div>
                    <div class="result-box" id="cleanup-result"></div>
                </div>
            </div>
        </div>
        
        <!-- تحسين الأداء -->
        <div class="col-md-6 col-lg-4 mb-4">
            <div class="card maintenance-card h-100">
                <div class="card-body text-center">
                    <i class="fas fa-tachometer-alt fa-3x text-success mb-3"></i>
                    <h5 class="card-title">تحسين الأداء</h5>
                    <p class="card-text">تحسين جداول قاعدة البيانات لأداء أفضل</p>
                    <button class="btn btn-success btn-maintenance" onclick="performAction('optimize')">
                        <i class="fas fa-rocket me-2"></i>تحسين الجداول
                    </button>
                    <div class="loading" id="optimize-loading">
                        <div class="spinner-border spinner-border-sm me-2"></div>
                        جاري التحسين...
                    </div>
                    <div class="result-box" id="optimize-result"></div>
                </div>
            </div>
        </div>
        
        <!-- فحص السلامة -->
        <div class="col-md-6 col-lg-4 mb-4">
            <div class="card maintenance-card h-100">
                <div class="card-body text-center">
                    <i class="fas fa-shield-alt fa-3x text-info mb-3"></i>
                    <h5 class="card-title">فحص السلامة</h5>
                    <p class="card-text">فحص سلامة البيانات واكتشاف المشاكل</p>
                    <button class="btn btn-info btn-maintenance" onclick="performAction('check_integrity')">
                        <i class="fas fa-search me-2"></i>فحص السلامة
                    </button>
                    <div class="loading" id="check_integrity-loading">
                        <div class="spinner-border spinner-border-sm me-2"></div>
                        جاري الفحص...
                    </div>
                    <div class="result-box" id="check_integrity-result"></div>
                </div>
            </div>
        </div>
        
        <!-- تقرير الأداء -->
        <div class="col-md-6 col-lg-4 mb-4">
            <div class="card maintenance-card h-100">
                <div class="card-body text-center">
                    <i class="fas fa-chart-bar fa-3x text-secondary mb-3"></i>
                    <h5 class="card-title">تقرير الأداء</h5>
                    <p class="card-text">إنشاء تقرير شامل عن أداء النظام</p>
                    <button class="btn btn-secondary btn-maintenance" onclick="performAction('performance_report')">
                        <i class="fas fa-file-alt me-2"></i>إنشاء التقرير
                    </button>
                    <div class="loading" id="performance_report-loading">
                        <div class="spinner-border spinner-border-sm me-2"></div>
                        جاري الإنشاء...
                    </div>
                    <div class="result-box" id="performance_report-result"></div>
                </div>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
function performAction(action) {
    const loadingEl = document.getElementById(action + '-loading');
    const resultEl = document.getElementById(action + '-result');
    
    // إظهار مؤشر التحميل
    loadingEl.style.display = 'block';
    resultEl.style.display = 'none';
    
    // إرسال الطلب
    fetch('', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: 'action=' + action
    })
    .then(response => response.json())
    .then(data => {
        loadingEl.style.display = 'none';
        resultEl.style.display = 'block';
        
        if (data.success) {
            resultEl.className = 'result-box alert alert-success';
            resultEl.innerHTML = getSuccessMessage(action, data);
        } else {
            resultEl.className = 'result-box alert alert-danger';
            resultEl.innerHTML = '<i class="fas fa-exclamation-circle me-2"></i>خطأ: ' + data.error;
        }
    })
    .catch(error => {
        loadingEl.style.display = 'none';
        resultEl.style.display = 'block';
        resultEl.className = 'result-box alert alert-danger';
        resultEl.innerHTML = '<i class="fas fa-exclamation-circle me-2"></i>خطأ في الاتصال: ' + error;
    });
}

function performCleanup() {
    const days = document.getElementById('cleanup-days').value;
    const loadingEl = document.getElementById('cleanup-loading');
    const resultEl = document.getElementById('cleanup-result');
    
    loadingEl.style.display = 'block';
    resultEl.style.display = 'none';
    
    fetch('', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: 'action=cleanup&days=' + days
    })
    .then(response => response.json())
    .then(data => {
        loadingEl.style.display = 'none';
        resultEl.style.display = 'block';
        
        if (data.success) {
            resultEl.className = 'result-box alert alert-success';
            resultEl.innerHTML = '<i class="fas fa-check-circle me-2"></i>تم حذف ' + data.deleted_records + ' سجل قديم';
        } else {
            resultEl.className = 'result-box alert alert-danger';
            resultEl.innerHTML = '<i class="fas fa-exclamation-circle me-2"></i>خطأ: ' + data.error;
        }
    })
    .catch(error => {
        loadingEl.style.display = 'none';
        resultEl.style.display = 'block';
        resultEl.className = 'result-box alert alert-danger';
        resultEl.innerHTML = '<i class="fas fa-exclamation-circle me-2"></i>خطأ في الاتصال: ' + error;
    });
}

function getSuccessMessage(action, data) {
    switch(action) {
        case 'backup':
            return '<i class="fas fa-check-circle me-2"></i>تم إنشاء النسخة الاحتياطية بنجاح<br><small>الحجم: ' + formatBytes(data.size) + '</small>';
        case 'optimize':
            return '<i class="fas fa-check-circle me-2"></i>تم تحسين ' + data.optimized_tables + ' جدول';
        case 'check_integrity':
            if (data.issues.length === 0) {
                return '<i class="fas fa-check-circle me-2"></i>لا توجد مشاكل في البيانات';
            } else {
                return '<i class="fas fa-exclamation-triangle me-2"></i>وُجدت ' + data.issues.length + ' مشكلة:<br>' + data.issues.join('<br>');
            }
        case 'performance_report':
            const report = data.report;
            return '<i class="fas fa-check-circle me-2"></i>تقرير الأداء:<br>' +
                   '<small>' +
                   'المعلمون النشطون: ' + report.active_teachers + '<br>' +
                   'الطلاب النشطون: ' + report.active_students + '<br>' +
                   'أولياء الأمور النشطون: ' + report.active_parents + '<br>' +
                   'معدل الحضور: ' + (report.attendance.attendance_rate || 0) + '%<br>' +
                   'حجم قاعدة البيانات: ' + report.database_size_mb + ' ميجابايت' +
                   '</small>';
        default:
            return '<i class="fas fa-check-circle me-2"></i>تم تنفيذ العملية بنجاح';
    }
}

function formatBytes(bytes) {
    if (bytes === 0) return '0 Bytes';
    const k = 1024;
    const sizes = ['Bytes', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
}
</script>

</body>
</html>

