-- security_updates.sql - جداول إضافية للأمان

-- جدول سجل نشاط المستخدمين
CREATE TABLE IF NOT EXISTS user_activity_log (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_type ENUM('teacher', 'distributor', 'parent') NOT NULL,
    user_id INT NOT NULL,
    action VARCHAR(255) NOT NULL,
    details TEXT,
    ip_address VARCHAR(45),
    user_agent TEXT,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    INDEX idx_user_activity (user_type, user_id, created_at),
    INDEX idx_activity_date (created_at)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- جدول جلسات المستخدمين النشطة
CREATE TABLE IF NOT EXISTS active_sessions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    session_id VARCHAR(255) UNIQUE NOT NULL,
    user_type ENUM('teacher', 'distributor', 'parent') NOT NULL,
    user_id INT NOT NULL,
    ip_address VARCHAR(45),
    user_agent TEXT,
    last_activity DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    INDEX idx_session_user (user_type, user_id),
    INDEX idx_session_activity (last_activity)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- جدول الإعدادات الأمنية
CREATE TABLE IF NOT EXISTS security_settings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    setting_name VARCHAR(100) UNIQUE NOT NULL,
    setting_value TEXT,
    description TEXT,
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- جدول تقارير الأمان
CREATE TABLE IF NOT EXISTS security_incidents (
    id INT AUTO_INCREMENT PRIMARY KEY,
    incident_type ENUM('failed_login', 'suspicious_activity', 'unauthorized_access', 'data_breach') NOT NULL,
    severity ENUM('low', 'medium', 'high', 'critical') DEFAULT 'medium',
    description TEXT NOT NULL,
    ip_address VARCHAR(45),
    user_agent TEXT,
    affected_user_type ENUM('teacher', 'distributor', 'parent'),
    affected_user_id INT,
    status ENUM('open', 'investigating', 'resolved', 'false_positive') DEFAULT 'open',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    resolved_at DATETIME NULL,
    INDEX idx_incident_type (incident_type, created_at),
    INDEX idx_incident_severity (severity, status)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- جدول النسخ الاحتياطية
CREATE TABLE IF NOT EXISTS backup_log (
    id INT AUTO_INCREMENT PRIMARY KEY,
    backup_type ENUM('full', 'incremental', 'differential') NOT NULL,
    backup_path VARCHAR(500),
    file_size BIGINT,
    status ENUM('started', 'completed', 'failed') DEFAULT 'started',
    started_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    completed_at DATETIME NULL,
    error_message TEXT,
    INDEX idx_backup_date (started_at),
    INDEX idx_backup_status (status)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- إدراج الإعدادات الأمنية الافتراضية
INSERT INTO security_settings (setting_name, setting_value, description) VALUES
('max_login_attempts', '5', 'عدد محاولات تسجيل الدخول الفاشلة المسموحة'),
('login_attempt_window', '15', 'النافزة الزمنية لمحاولات تسجيل الدخول (بالدقائق)'),
('session_timeout', '30', 'مهلة انتهاء الجلسة (بالدقائق)'),
('password_min_length', '8', 'الحد الأدنى لطول كلمة المرور'),
('password_require_uppercase', '1', 'يتطلب حرف كبير في كلمة المرور'),
('password_require_lowercase', '1', 'يتطلب حرف صغير في كلمة المرور'),
('password_require_number', '1', 'يتطلب رقم في كلمة المرور'),
('password_require_special', '0', 'يتطلب رمز خاص في كلمة المرور'),
('enable_two_factor', '0', 'تفعيل المصادقة الثنائية'),
('backup_frequency', 'daily', 'تكرار النسخ الاحتياطية'),
('log_retention_days', '90', 'مدة الاحتفاظ بالسجلات (بالأيام)');

-- إنشاء فهارس إضافية لتحسين الأداء
CREATE INDEX idx_teachers_email_active ON teachers(email, is_active);
CREATE INDEX idx_parents_email_active ON parents(email, is_active);
CREATE INDEX idx_students_teacher_parent ON students(teacher_id, parent_id);
CREATE INDEX idx_messages_receiver ON parent_teacher_messages(receiver_type, receiver_id, is_read);
CREATE INDEX idx_messages_sender ON parent_teacher_messages(sender_type, sender_id, sent_at);

-- إنشاء مشاهدات (Views) لتسهيل الاستعلامات
CREATE OR REPLACE VIEW student_parent_view AS
SELECT 
    s.student_id,
    s.name as student_name,
    s.grade_level,
    s.phone as student_phone,
    s.payment_status,
    t.id as teacher_id,
    t.name as teacher_name,
    t.email as teacher_email,
    p.id as parent_id,
    p.name as parent_name,
    p.email as parent_email,
    p.phone as parent_phone,
    sp.relationship,
    sp.is_primary
FROM students s
LEFT JOIN teachers t ON s.teacher_id = t.id
LEFT JOIN student_parent sp ON s.student_id = sp.student_id
LEFT JOIN parents p ON sp.parent_id = p.id OR s.parent_id = p.id;

-- مشاهدة للإحصائيات السريعة
CREATE OR REPLACE VIEW dashboard_stats AS
SELECT 
    (SELECT COUNT(*) FROM teachers WHERE is_active = 1) as active_teachers,
    (SELECT COUNT(*) FROM teachers WHERE is_active = 0) as inactive_teachers,
    (SELECT COUNT(*) FROM students) as total_students,
    (SELECT COUNT(*) FROM parents WHERE is_active = 1) as active_parents,
    (SELECT COUNT(*) FROM parent_teacher_messages WHERE is_read = 0) as unread_messages,
    (SELECT SUM(due_amount) FROM payments WHERE due_amount > 0) as total_due_amount;

-- إجراء مخزن لتنظيف البيانات القديمة
DELIMITER //
CREATE PROCEDURE CleanupOldData()
BEGIN
    DECLARE retention_days INT DEFAULT 90;
    
    -- الحصول على مدة الاحتفاظ من الإعدادات
    SELECT CAST(setting_value AS UNSIGNED) INTO retention_days 
    FROM security_settings 
    WHERE setting_name = 'log_retention_days';
    
    -- حذف سجلات النشاط القديمة
    DELETE FROM user_activity_log 
    WHERE created_at < DATE_SUB(NOW(), INTERVAL retention_days DAY);
    
    -- حذف محاولات تسجيل الدخول القديمة
    DELETE FROM login_attempts 
    WHERE attempt_time < DATE_SUB(NOW(), INTERVAL retention_days DAY);
    
    -- حذف الجلسات المنتهية الصلاحية
    DELETE FROM active_sessions 
    WHERE last_activity < DATE_SUB(NOW(), INTERVAL 1 DAY);
    
    -- حذف رموز CSRF المنتهية الصلاحية
    DELETE FROM csrf_tokens 
    WHERE expires_at < NOW();
    
END //
DELIMITER ;

-- إنشاء مستخدم قاعدة بيانات محدود الصلاحيات للتطبيق
-- CREATE USER 'td_app_user'@'localhost' IDENTIFIED BY 'secure_password_here';
-- GRANT SELECT, INSERT, UPDATE, DELETE ON td_db.* TO 'td_app_user'@'localhost';
-- GRANT EXECUTE ON PROCEDURE td_db.CleanupOldData TO 'td_app_user'@'localhost';
-- FLUSH PRIVILEGES;

