<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a teacher
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['user_id'];
$message = '';
$error = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'mark_attendance':
                $group_id = $_POST['group_id'];
                $date = $_POST['date'];
                $attendance_data = $_POST['attendance'] ?? [];
                
                try {
                    $pdo->beginTransaction();
                    
                    // Delete existing attendance for this group and date
                    $stmt = $pdo->prepare("DELETE FROM attendance WHERE student_id IN (SELECT student_id FROM students WHERE group_id = ?) AND date = ?");
                    $stmt->execute([$group_id, $date]);
                    
                    // Insert new attendance records
                    foreach ($attendance_data as $student_id => $status) {
                        $stmt = $pdo->prepare("INSERT INTO attendance (student_id, date, status, recorded_by) VALUES (?, ?, ?, ?)");
                        $stmt->execute([$student_id, $date, $status, $teacher_id]);
                    }
                    
                    $pdo->commit();
                    $message = "تم تسجيل الحضور بنجاح";
                } catch (PDOException $e) {
                    $pdo->rollBack();
                    $error = "خطأ في تسجيل الحضور: " . $e->getMessage();
                }
                break;
                
            case 'bulk_attendance':
                $group_id = $_POST['group_id'];
                $start_date = $_POST['start_date'];
                $end_date = $_POST['end_date'];
                $status = $_POST['status'];
                
                try {
                    // Get all students in the group
                    $stmt = $pdo->prepare("SELECT student_id FROM students WHERE group_id = ?");
                    $stmt->execute([$group_id]);
                    $students = $stmt->fetchAll();
                    
                    if (!empty($students)) {
                        $pdo->beginTransaction();
                        
                        // Generate date range
                        $current_date = new DateTime($start_date);
                        $end_date_obj = new DateTime($end_date);
                        
                        while ($current_date <= $end_date_obj) {
                            $date_str = $current_date->format('Y-m-d');
                            
                            foreach ($students as $student) {
                                // Check if attendance already exists
                                $stmt = $pdo->prepare("SELECT id FROM attendance WHERE student_id = ? AND date = ?");
                                $stmt->execute([$student['student_id'], $date_str]);
                                
                                if (!$stmt->fetch()) {
                                    // Insert attendance record
                                    $stmt = $pdo->prepare("INSERT INTO attendance (student_id, date, status, recorded_by) VALUES (?, ?, ?, ?)");
                                    $stmt->execute([$student['student_id'], $date_str, $status, $teacher_id]);
                                }
                            }
                            
                            $current_date->add(new DateInterval('P1D'));
                        }
                        
                        $pdo->commit();
                        $message = "تم تسجيل الحضور المجمع بنجاح";
                    }
                } catch (Exception $e) {
                    $pdo->rollBack();
                    $error = "خطأ في تسجيل الحضور المجمع: " . $e->getMessage();
                }
                break;
        }
    }
}

// Get filter parameters
$selected_group = $_GET['group'] ?? '';
$selected_date = $_GET['date'] ?? date('Y-m-d');
$view_mode = $_GET['view'] ?? 'daily';

// Get all groups for this teacher
$stmt = $pdo->prepare("SELECT id, name, type, schedule_time, schedule_period FROM study_groups WHERE teacher_id = ? AND is_active = 1 ORDER BY name");
$stmt->execute([$teacher_id]);
$groups = $stmt->fetchAll();

// Get students and attendance for selected group and date
$students_with_attendance = [];
if ($selected_group) {
    if ($view_mode === 'daily') {
        $stmt = $pdo->prepare("
            SELECT 
                s.student_id,
                s.name,
                s.phone,
                p.name as parent_name,
                p.phone as parent_phone,
                a.status,
                a.date as attendance_date
            FROM students s
            LEFT JOIN parents p ON s.parent_id = p.id
            LEFT JOIN attendance a ON s.student_id = a.student_id AND a.date = ?
            WHERE s.group_id = ?
            ORDER BY s.name
        ");
        $stmt->execute([$selected_date, $selected_group]);
        $students_with_attendance = $stmt->fetchAll();
    } else {
        // Weekly or monthly view
        $start_date = $selected_date;
        $end_date = $selected_date;
        
        if ($view_mode === 'weekly') {
            $start_date = date('Y-m-d', strtotime('monday this week', strtotime($selected_date)));
            $end_date = date('Y-m-d', strtotime('sunday this week', strtotime($selected_date)));
        } elseif ($view_mode === 'monthly') {
            $start_date = date('Y-m-01', strtotime($selected_date));
            $end_date = date('Y-m-t', strtotime($selected_date));
        }
        
        $stmt = $pdo->prepare("
            SELECT 
                s.student_id,
                s.name,
                COUNT(CASE WHEN a.status = 'present' THEN 1 END) as present_count,
                COUNT(CASE WHEN a.status = 'absent' THEN 1 END) as absent_count,
                COUNT(CASE WHEN a.status = 'late' THEN 1 END) as late_count,
                COUNT(a.id) as total_sessions,
                ROUND((COUNT(CASE WHEN a.status = 'present' THEN 1 END) / COUNT(a.id)) * 100, 2) as attendance_percentage
            FROM students s
            LEFT JOIN attendance a ON s.student_id = a.student_id 
                AND a.date BETWEEN ? AND ?
            WHERE s.group_id = ?
            GROUP BY s.student_id, s.name
            ORDER BY s.name
        ");
        $stmt->execute([$start_date, $end_date, $selected_group]);
        $students_with_attendance = $stmt->fetchAll();
    }
}

// Get group info
$group_info = null;
if ($selected_group) {
    $stmt = $pdo->prepare("SELECT * FROM study_groups WHERE id = ? AND teacher_id = ?");
    $stmt->execute([$selected_group, $teacher_id]);
    $group_info = $stmt->fetch();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تسجيل الحضور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .attendance-card { transition: transform 0.2s; }
        .attendance-card:hover { transform: translateY(-2px); }
        .status-present { background-color: #d4edda; border-color: #c3e6cb; }
        .status-absent { background-color: #f8d7da; border-color: #f5c6cb; }
        .status-late { background-color: #fff3cd; border-color: #ffeaa7; }
        .attendance-grid { display: grid; grid-template-columns: repeat(auto-fit, minmax(300px, 1fr)); gap: 1rem; }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-user-check me-2"></i>تسجيل الحضور</h2>
                        <div>
                            <a href="revenue.php" class="btn btn-outline-info me-2">
                                <i class="fas fa-chart-line me-2"></i>تقارير الإيرادات
                            </a>
                            <a href="dashboard.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                            </a>
                        </div>
                    </div>

                    <?php if ($message): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($message) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if ($error): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($error) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <!-- Filters -->
                    <div class="card mb-4">
                        <div class="card-body">
                            <form method="GET" class="row g-3">
                                <div class="col-md-4">
                                    <label for="group" class="form-label">المجموعة *</label>
                                    <select class="form-select" id="group" name="group" required onchange="this.form.submit()">
                                        <option value="">اختر المجموعة</option>
                                        <?php foreach ($groups as $group): ?>
                                            <option value="<?= $group['id'] ?>" <?= $selected_group == $group['id'] ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($group['name']) ?> 
                                                (<?= $group['type'] === 'public' ? 'عامة' : ($group['type'] === 'private' ? 'خاصة' : 'فردية') ?>)
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-3">
                                    <label for="date" class="form-label">التاريخ</label>
                                    <input type="date" class="form-control" id="date" name="date" value="<?= $selected_date ?>" onchange="this.form.submit()">
                                </div>
                                <div class="col-md-3">
                                    <label for="view" class="form-label">نوع العرض</label>
                                    <select class="form-select" id="view" name="view" onchange="this.form.submit()">
                                        <option value="daily" <?= $view_mode === 'daily' ? 'selected' : '' ?>>يومي</option>
                                        <option value="weekly" <?= $view_mode === 'weekly' ? 'selected' : '' ?>>أسبوعي</option>
                                        <option value="monthly" <?= $view_mode === 'monthly' ? 'selected' : '' ?>>شهري</option>
                                    </select>
                                </div>
                                <div class="col-md-2">
                                    <label class="form-label">&nbsp;</label>
                                    <button type="submit" class="btn btn-primary w-100">
                                        <i class="fas fa-search me-2"></i>عرض
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>

                    <?php if ($group_info): ?>
                        <!-- Group Info -->
                        <div class="card mb-4">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-8">
                                        <h5 class="mb-1"><?= htmlspecialchars($group_info['name']) ?></h5>
                                        <p class="text-muted mb-0">
                                            <i class="fas fa-clock me-2"></i><?= htmlspecialchars($group_info['schedule_time']) ?>
                                            <span class="badge bg-light text-dark ms-2"><?= $group_info['schedule_period'] === 'morning' ? 'صباحاً' : 'مساءً' ?></span>
                                        </p>
                                    </div>
                                    <div class="col-md-4 text-end">
                                        <button type="button" class="btn btn-outline-primary" data-bs-toggle="modal" data-bs-target="#bulkAttendanceModal">
                                            <i class="fas fa-calendar-plus me-2"></i>تسجيل مجمع
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <?php if ($view_mode === 'daily'): ?>
                            <!-- Daily Attendance Form -->
                            <?php if (!empty($students_with_attendance)): ?>
                                <form method="POST">
                                    <input type="hidden" name="action" value="mark_attendance">
                                    <input type="hidden" name="group_id" value="<?= $selected_group ?>">
                                    <input type="hidden" name="date" value="<?= $selected_date ?>">
                                    
                                    <div class="card">
                                        <div class="card-header d-flex justify-content-between align-items-center">
                                            <h5 class="mb-0">تسجيل الحضور - <?= date('d/m/Y', strtotime($selected_date)) ?></h5>
                                            <button type="submit" class="btn btn-success">
                                                <i class="fas fa-save me-2"></i>حفظ الحضور
                                            </button>
                                        </div>
                                        <div class="card-body">
                                            <div class="attendance-grid">
                                                <?php foreach ($students_with_attendance as $student): ?>
                                                    <div class="card attendance-card <?= $student['status'] ? 'status-' . $student['status'] : '' ?>">
                                                        <div class="card-body">
                                                            <h6 class="card-title"><?= htmlspecialchars($student['name']) ?></h6>
                                                            <p class="card-text small text-muted">
                                                                <i class="fas fa-phone me-1"></i><?= htmlspecialchars($student['phone'] ?? 'غير محدد') ?><br>
                                                                <i class="fas fa-user me-1"></i><?= htmlspecialchars($student['parent_name'] ?? 'غير محدد') ?>
                                                                <?php if ($student['parent_phone']): ?>
                                                                    <br><i class="fas fa-phone me-1"></i><?= htmlspecialchars($student['parent_phone']) ?>
                                                                <?php endif; ?>
                                                            </p>
                                                            <div class="btn-group w-100" role="group">
                                                                <input type="radio" class="btn-check" name="attendance[<?= $student['student_id'] ?>]" 
                                                                       id="present_<?= $student['student_id'] ?>" value="present" 
                                                                       <?= $student['status'] === 'present' ? 'checked' : '' ?>>
                                                                <label class="btn btn-outline-success" for="present_<?= $student['student_id'] ?>">
                                                                    <i class="fas fa-check"></i> حاضر
                                                                </label>
                                                                
                                                                <input type="radio" class="btn-check" name="attendance[<?= $student['student_id'] ?>]" 
                                                                       id="late_<?= $student['student_id'] ?>" value="late" 
                                                                       <?= $student['status'] === 'late' ? 'checked' : '' ?>>
                                                                <label class="btn btn-outline-warning" for="late_<?= $student['student_id'] ?>">
                                                                    <i class="fas fa-clock"></i> متأخر
                                                                </label>
                                                                
                                                                <input type="radio" class="btn-check" name="attendance[<?= $student['student_id'] ?>]" 
                                                                       id="absent_<?= $student['student_id'] ?>" value="absent" 
                                                                       <?= $student['status'] === 'absent' ? 'checked' : '' ?>>
                                                                <label class="btn btn-outline-danger" for="absent_<?= $student['student_id'] ?>">
                                                                    <i class="fas fa-times"></i> غائب
                                                                </label>
                                                            </div>
                                                        </div>
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            <?php else: ?>
                                <div class="card">
                                    <div class="card-body text-center py-5">
                                        <i class="fas fa-user-graduate fa-3x text-muted mb-3"></i>
                                        <p class="text-muted">لا توجد طلاب في هذه المجموعة</p>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php else: ?>
                            <!-- Weekly/Monthly Attendance Report -->
                            <?php if (!empty($students_with_attendance)): ?>
                                <div class="card">
                                    <div class="card-header">
                                        <h5 class="mb-0">تقرير الحضور - <?= $view_mode === 'weekly' ? 'أسبوعي' : 'شهري' ?></h5>
                                    </div>
                                    <div class="card-body">
                                        <div class="table-responsive">
                                            <table class="table table-striped">
                                                <thead>
                                                    <tr>
                                                        <th>اسم الطالب</th>
                                                        <th>حاضر</th>
                                                        <th>متأخر</th>
                                                        <th>غائب</th>
                                                        <th>إجمالي الحصص</th>
                                                        <th>نسبة الحضور</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php foreach ($students_with_attendance as $student): ?>
                                                        <tr>
                                                            <td><?= htmlspecialchars($student['name']) ?></td>
                                                            <td><span class="badge bg-success"><?= $student['present_count'] ?></span></td>
                                                            <td><span class="badge bg-warning"><?= $student['late_count'] ?></span></td>
                                                            <td><span class="badge bg-danger"><?= $student['absent_count'] ?></span></td>
                                                            <td><?= $student['total_sessions'] ?></td>
                                                            <td>
                                                                <div class="progress" style="height: 20px;">
                                                                    <div class="progress-bar" role="progressbar" 
                                                                         style="width: <?= $student['attendance_percentage'] ?>%">
                                                                        <?= $student['attendance_percentage'] ?>%
                                                                    </div>
                                                                </div>
                                                            </td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Bulk Attendance Modal -->
    <div class="modal fade" id="bulkAttendanceModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <input type="hidden" name="action" value="bulk_attendance">
                    <input type="hidden" name="group_id" value="<?= $selected_group ?>">
                    
                    <div class="modal-header">
                        <h5 class="modal-title">تسجيل حضور مجمع</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="start_date" class="form-label">من تاريخ</label>
                            <input type="date" class="form-control" id="start_date" name="start_date" required>
                        </div>
                        <div class="mb-3">
                            <label for="end_date" class="form-label">إلى تاريخ</label>
                            <input type="date" class="form-control" id="end_date" name="end_date" required>
                        </div>
                        <div class="mb-3">
                            <label for="status" class="form-label">حالة الحضور</label>
                            <select class="form-select" id="status" name="status" required>
                                <option value="present">حاضر</option>
                                <option value="absent">غائب</option>
                                <option value="late">متأخر</option>
                            </select>
                        </div>
                        <div class="alert alert-info">
                            <i class="fas fa-info-circle me-2"></i>
                            سيتم تسجيل الحضور لجميع طلاب المجموعة في الفترة المحددة
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                        <button type="submit" class="btn btn-primary">تسجيل الحضور</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Update attendance card styling based on selection
        document.querySelectorAll('input[type="radio"]').forEach(radio => {
            radio.addEventListener('change', function() {
                const card = this.closest('.attendance-card');
                card.className = 'card attendance-card status-' + this.value;
            });
        });
        
        // Set default dates for bulk attendance
        document.getElementById('start_date').value = '<?= $selected_date ?>';
        document.getElementById('end_date').value = '<?= $selected_date ?>';
    </script>
</body>
</html>

