<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a teacher
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['user_id'];
$message = '';
$error = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'create_evaluation_type':
                $name = trim($_POST['name']);
                $description = trim($_POST['description']);
                $max_score = floatval($_POST['max_score']);
                $weight = floatval($_POST['weight']);
                
                if (!empty($name) && $max_score > 0) {
                    try {
                        $stmt = $pdo->prepare("INSERT INTO evaluation_types (name, description, max_score, weight, teacher_id) VALUES (?, ?, ?, ?, ?)");
                        $stmt->execute([$name, $description, $max_score, $weight, $teacher_id]);
                        $message = "تم إنشاء نوع التقييم بنجاح";
                    } catch (PDOException $e) {
                        $error = "خطأ في إنشاء نوع التقييم: " . $e->getMessage();
                    }
                } else {
                    $error = "اسم التقييم والدرجة النهائية مطلوبان";
                }
                break;
                
            case 'add_evaluation':
                $student_id = $_POST['student_id'];
                $evaluation_type_id = $_POST['evaluation_type_id'];
                $score = floatval($_POST['score']);
                $notes = trim($_POST['notes']);
                $evaluation_date = $_POST['evaluation_date'];
                
                try {
                    $stmt = $pdo->prepare("INSERT INTO student_evaluations (student_id, evaluation_type_id, score, notes, evaluation_date, teacher_id) VALUES (?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$student_id, $evaluation_type_id, $score, $notes, $evaluation_date, $teacher_id]);
                    $message = "تم إضافة التقييم بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في إضافة التقييم: " . $e->getMessage();
                }
                break;
                
            case 'update_evaluation':
                $evaluation_id = $_POST['evaluation_id'];
                $score = floatval($_POST['score']);
                $notes = trim($_POST['notes']);
                $evaluation_date = $_POST['evaluation_date'];
                
                try {
                    $stmt = $pdo->prepare("UPDATE student_evaluations SET score = ?, notes = ?, evaluation_date = ? WHERE id = ? AND teacher_id = ?");
                    $stmt->execute([$score, $notes, $evaluation_date, $evaluation_id, $teacher_id]);
                    $message = "تم تحديث التقييم بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في تحديث التقييم: " . $e->getMessage();
                }
                break;
                
            case 'delete_evaluation':
                $evaluation_id = $_POST['evaluation_id'];
                
                try {
                    $stmt = $pdo->prepare("DELETE FROM student_evaluations WHERE id = ? AND teacher_id = ?");
                    $stmt->execute([$evaluation_id, $teacher_id]);
                    $message = "تم حذف التقييم بنجاح";
                } catch (PDOException $e) {
                    $error = "خطأ في حذف التقييم: " . $e->getMessage();
                }
                break;
        }
    }
}

// Get filter parameters
$selected_group = $_GET['group'] ?? '';
$selected_student = $_GET['student'] ?? '';
$view_mode = $_GET['view'] ?? 'overview';

// Get all groups for this teacher
$stmt = $pdo->prepare("SELECT id, name, type FROM study_groups WHERE teacher_id = ? AND is_active = 1 ORDER BY name");
$stmt->execute([$teacher_id]);
$groups = $stmt->fetchAll();

// Get students based on selected group
$students = [];
if ($selected_group) {
    $stmt = $pdo->prepare("SELECT student_id, name FROM students WHERE group_id = ? ORDER BY name");
    $stmt->execute([$selected_group]);
    $students = $stmt->fetchAll();
}

// Get evaluation types for this teacher
$stmt = $pdo->prepare("SELECT * FROM evaluation_types WHERE teacher_id = ? ORDER BY name");
$stmt->execute([$teacher_id]);
$evaluation_types = $stmt->fetchAll();

// Get evaluations based on filters
$evaluations = [];
$student_stats = [];

if ($view_mode === 'overview' && $selected_group) {
    // Get overview of all students in the group
    $stmt = $pdo->prepare("
        SELECT 
            s.student_id,
            s.name,
            COUNT(se.id) as total_evaluations,
            AVG(se.score) as average_score,
            SUM(se.score * et.weight) / SUM(et.weight) as weighted_average,
            MAX(se.evaluation_date) as last_evaluation_date
        FROM students s
        LEFT JOIN student_evaluations se ON s.student_id = se.student_id
        LEFT JOIN evaluation_types et ON se.evaluation_type_id = et.id
        WHERE s.group_id = ?
        GROUP BY s.student_id, s.name
        ORDER BY s.name
    ");
    $stmt->execute([$selected_group]);
    $student_stats = $stmt->fetchAll();
} elseif ($view_mode === 'detailed' && $selected_student) {
    // Get detailed evaluations for specific student
    $stmt = $pdo->prepare("
        SELECT 
            se.*,
            et.name as evaluation_type_name,
            et.max_score,
            et.weight,
            (se.score / et.max_score * 100) as percentage
        FROM student_evaluations se
        JOIN evaluation_types et ON se.evaluation_type_id = et.id
        WHERE se.student_id = ? AND se.teacher_id = ?
        ORDER BY se.evaluation_date DESC
    ");
    $stmt->execute([$selected_student, $teacher_id]);
    $evaluations = $stmt->fetchAll();
    
    // Get student info
    $stmt = $pdo->prepare("SELECT name FROM students WHERE student_id = ?");
    $stmt->execute([$selected_student]);
    $student_info = $stmt->fetch();
}

// Get evaluation for editing if requested
$edit_evaluation = null;
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $stmt = $pdo->prepare("SELECT * FROM student_evaluations WHERE id = ? AND teacher_id = ?");
    $stmt->execute([$_GET['edit'], $teacher_id]);
    $edit_evaluation = $stmt->fetch();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>نظام التقييمات</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .evaluation-card { transition: transform 0.2s; }
        .evaluation-card:hover { transform: translateY(-2px); }
        .score-excellent { color: #28a745; }
        .score-good { color: #17a2b8; }
        .score-average { color: #ffc107; }
        .score-poor { color: #dc3545; }
        .chart-container { position: relative; height: 300px; }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-star me-2"></i>نظام التقييمات</h2>
                        <div>
                            <button type="button" class="btn btn-outline-primary me-2" data-bs-toggle="modal" data-bs-target="#evaluationTypeModal">
                                <i class="fas fa-plus me-2"></i>نوع تقييم جديد
                            </button>
                            <a href="dashboard.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                            </a>
                        </div>
                    </div>

                    <?php if ($message): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($message) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <?php if ($error): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?= htmlspecialchars($error) ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                    <?php endif; ?>

                    <!-- Filters -->
                    <div class="card mb-4">
                        <div class="card-body">
                            <form method="GET" class="row g-3">
                                <div class="col-md-4">
                                    <label for="group" class="form-label">المجموعة</label>
                                    <select class="form-select" id="group" name="group" onchange="this.form.submit()">
                                        <option value="">اختر المجموعة</option>
                                        <?php foreach ($groups as $group): ?>
                                            <option value="<?= $group['id'] ?>" <?= $selected_group == $group['id'] ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($group['name']) ?> 
                                                (<?= $group['type'] === 'public' ? 'عامة' : ($group['type'] === 'private' ? 'خاصة' : 'فردية') ?>)
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-4">
                                    <label for="student" class="form-label">الطالب</label>
                                    <select class="form-select" id="student" name="student" onchange="this.form.submit()">
                                        <option value="">جميع الطلاب</option>
                                        <?php foreach ($students as $student): ?>
                                            <option value="<?= $student['student_id'] ?>" <?= $selected_student == $student['student_id'] ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($student['name']) ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-4">
                                    <label for="view" class="form-label">نوع العرض</label>
                                    <select class="form-select" id="view" name="view" onchange="this.form.submit()">
                                        <option value="overview" <?= $view_mode === 'overview' ? 'selected' : '' ?>>نظرة عامة</option>
                                        <option value="detailed" <?= $view_mode === 'detailed' ? 'selected' : '' ?>>تفصيلي</option>
                                    </select>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- Evaluation Types Summary -->
                    <?php if (!empty($evaluation_types)): ?>
                        <div class="card mb-4">
                            <div class="card-header">
                                <h5 class="mb-0">أنواع التقييمات المتاحة</h5>
                            </div>
                            <div class="card-body">
                                <div class="row">
                                    <?php foreach ($evaluation_types as $type): ?>
                                        <div class="col-md-3 mb-3">
                                            <div class="card evaluation-card">
                                                <div class="card-body text-center">
                                                    <h6 class="card-title"><?= htmlspecialchars($type['name']) ?></h6>
                                                    <p class="card-text small text-muted"><?= htmlspecialchars($type['description']) ?></p>
                                                    <div class="d-flex justify-content-between">
                                                        <small>الدرجة النهائية: <strong><?= $type['max_score'] ?></strong></small>
                                                        <small>الوزن: <strong><?= $type['weight'] ?></strong></small>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>

                    <?php if ($view_mode === 'overview' && !empty($student_stats)): ?>
                        <!-- Students Overview -->
                        <div class="card">
                            <div class="card-header d-flex justify-content-between align-items-center">
                                <h5 class="mb-0">نظرة عامة على الطلاب</h5>
                                <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addEvaluationModal">
                                    <i class="fas fa-plus me-2"></i>إضافة تقييم
                                </button>
                            </div>
                            <div class="card-body">
                                <div class="table-responsive">
                                    <table class="table table-striped">
                                        <thead>
                                            <tr>
                                                <th>اسم الطالب</th>
                                                <th>عدد التقييمات</th>
                                                <th>المتوسط العام</th>
                                                <th>المتوسط المرجح</th>
                                                <th>آخر تقييم</th>
                                                <th>الإجراءات</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($student_stats as $student): ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($student['name']) ?></td>
                                                    <td><span class="badge bg-info"><?= $student['total_evaluations'] ?></span></td>
                                                    <td>
                                                        <?php if ($student['average_score']): ?>
                                                            <span class="<?= $student['average_score'] >= 85 ? 'score-excellent' : ($student['average_score'] >= 70 ? 'score-good' : ($student['average_score'] >= 50 ? 'score-average' : 'score-poor')) ?>">
                                                                <?= number_format($student['average_score'], 2) ?>
                                                            </span>
                                                        <?php else: ?>
                                                            <span class="text-muted">لا توجد تقييمات</span>
                                                        <?php endif; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($student['weighted_average']): ?>
                                                            <span class="<?= $student['weighted_average'] >= 85 ? 'score-excellent' : ($student['weighted_average'] >= 70 ? 'score-good' : ($student['weighted_average'] >= 50 ? 'score-average' : 'score-poor')) ?>">
                                                                <?= number_format($student['weighted_average'], 2) ?>
                                                            </span>
                                                        <?php else: ?>
                                                            <span class="text-muted">لا توجد تقييمات</span>
                                                        <?php endif; ?>
                                                    </td>
                                                    <td>
                                                        <?= $student['last_evaluation_date'] ? date('d/m/Y', strtotime($student['last_evaluation_date'])) : 'لا يوجد' ?>
                                                    </td>
                                                    <td>
                                                        <a href="?group=<?= $selected_group ?>&student=<?= $student['student_id'] ?>&view=detailed" 
                                                           class="btn btn-sm btn-outline-primary">
                                                            <i class="fas fa-eye"></i> عرض التفاصيل
                                                        </a>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                    <?php elseif ($view_mode === 'detailed' && $selected_student): ?>
                        <!-- Detailed Student Evaluations -->
                        <div class="row mb-4">
                            <div class="col-md-8">
                                <div class="card">
                                    <div class="card-header d-flex justify-content-between align-items-center">
                                        <h5 class="mb-0">تقييمات الطالب: <?= htmlspecialchars($student_info['name'] ?? '') ?></h5>
                                        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addEvaluationModal">
                                            <i class="fas fa-plus me-2"></i>إضافة تقييم
                                        </button>
                                    </div>
                                    <div class="card-body">
                                        <?php if (empty($evaluations)): ?>
                                            <div class="text-center py-5">
                                                <i class="fas fa-star fa-3x text-muted mb-3"></i>
                                                <p class="text-muted">لا توجد تقييمات لهذا الطالب</p>
                                            </div>
                                        <?php else: ?>
                                            <div class="table-responsive">
                                                <table class="table">
                                                    <thead>
                                                        <tr>
                                                            <th>نوع التقييم</th>
                                                            <th>الدرجة</th>
                                                            <th>النسبة المئوية</th>
                                                            <th>التاريخ</th>
                                                            <th>الملاحظات</th>
                                                            <th>الإجراءات</th>
                                                        </tr>
                                                    </thead>
                                                    <tbody>
                                                        <?php foreach ($evaluations as $evaluation): ?>
                                                            <tr>
                                                                <td><?= htmlspecialchars($evaluation['evaluation_type_name']) ?></td>
                                                                <td>
                                                                    <span class="<?= $evaluation['percentage'] >= 85 ? 'score-excellent' : ($evaluation['percentage'] >= 70 ? 'score-good' : ($evaluation['percentage'] >= 50 ? 'score-average' : 'score-poor')) ?>">
                                                                        <?= $evaluation['score'] ?> / <?= $evaluation['max_score'] ?>
                                                                    </span>
                                                                </td>
                                                                <td>
                                                                    <div class="progress" style="height: 20px;">
                                                                        <div class="progress-bar <?= $evaluation['percentage'] >= 85 ? 'bg-success' : ($evaluation['percentage'] >= 70 ? 'bg-info' : ($evaluation['percentage'] >= 50 ? 'bg-warning' : 'bg-danger')) ?>" 
                                                                             role="progressbar" style="width: <?= $evaluation['percentage'] ?>%">
                                                                            <?= number_format($evaluation['percentage'], 1) ?>%
                                                                        </div>
                                                                    </div>
                                                                </td>
                                                                <td><?= date('d/m/Y', strtotime($evaluation['evaluation_date'])) ?></td>
                                                                <td><?= htmlspecialchars($evaluation['notes']) ?></td>
                                                                <td>
                                                                    <div class="btn-group" role="group">
                                                                        <a href="?group=<?= $selected_group ?>&student=<?= $selected_student ?>&view=detailed&edit=<?= $evaluation['id'] ?>" 
                                                                           class="btn btn-sm btn-outline-primary">
                                                                            <i class="fas fa-edit"></i>
                                                                        </a>
                                                                        <form method="POST" style="display: inline;" 
                                                                              onsubmit="return confirm('هل أنت متأكد من حذف هذا التقييم؟')">
                                                                            <input type="hidden" name="action" value="delete_evaluation">
                                                                            <input type="hidden" name="evaluation_id" value="<?= $evaluation['id'] ?>">
                                                                            <button type="submit" class="btn btn-sm btn-outline-danger">
                                                                                <i class="fas fa-trash"></i>
                                                                            </button>
                                                                        </form>
                                                                    </div>
                                                                </td>
                                                            </tr>
                                                        <?php endforeach; ?>
                                                    </tbody>
                                                </table>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <!-- Student Performance Chart -->
                                <div class="card">
                                    <div class="card-header">
                                        <h6 class="mb-0">أداء الطالب</h6>
                                    </div>
                                    <div class="card-body">
                                        <div class="chart-container">
                                            <canvas id="studentChart"></canvas>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Add Evaluation Type Modal -->
    <div class="modal fade" id="evaluationTypeModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <input type="hidden" name="action" value="create_evaluation_type">
                    
                    <div class="modal-header">
                        <h5 class="modal-title">إنشاء نوع تقييم جديد</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="name" class="form-label">اسم التقييم *</label>
                            <input type="text" class="form-control" id="name" name="name" required 
                                   placeholder="مثال: امتحان نصف الفصل">
                        </div>
                        <div class="mb-3">
                            <label for="description" class="form-label">الوصف</label>
                            <textarea class="form-control" id="description" name="description" rows="3" 
                                      placeholder="وصف مختصر لنوع التقييم"></textarea>
                        </div>
                        <div class="mb-3">
                            <label for="max_score" class="form-label">الدرجة النهائية *</label>
                            <input type="number" step="0.01" class="form-control" id="max_score" name="max_score" required>
                        </div>
                        <div class="mb-3">
                            <label for="weight" class="form-label">الوزن النسبي *</label>
                            <input type="number" step="0.01" class="form-control" id="weight" name="weight" required 
                                   placeholder="مثال: 1.0 للوزن العادي، 2.0 للوزن المضاعف">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                        <button type="submit" class="btn btn-primary">إنشاء نوع التقييم</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Add/Edit Evaluation Modal -->
    <div class="modal fade" id="addEvaluationModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <input type="hidden" name="action" value="<?= $edit_evaluation ? 'update_evaluation' : 'add_evaluation' ?>">
                    <?php if ($edit_evaluation): ?>
                        <input type="hidden" name="evaluation_id" value="<?= $edit_evaluation['id'] ?>">
                    <?php endif; ?>
                    
                    <div class="modal-header">
                        <h5 class="modal-title"><?= $edit_evaluation ? 'تعديل التقييم' : 'إضافة تقييم جديد' ?></h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <?php if (!$edit_evaluation): ?>
                            <div class="mb-3">
                                <label for="student_id" class="form-label">الطالب *</label>
                                <select class="form-select" id="student_id" name="student_id" required>
                                    <option value="">اختر الطالب</option>
                                    <?php foreach ($students as $student): ?>
                                        <option value="<?= $student['student_id'] ?>" <?= $selected_student == $student['student_id'] ? 'selected' : '' ?>>
                                            <?= htmlspecialchars($student['name']) ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>
                        <div class="mb-3">
                            <label for="evaluation_type_id" class="form-label">نوع التقييم *</label>
                            <select class="form-select" id="evaluation_type_id" name="evaluation_type_id" required>
                                <option value="">اختر نوع التقييم</option>
                                <?php foreach ($evaluation_types as $type): ?>
                                    <option value="<?= $type['id'] ?>" data-max-score="<?= $type['max_score'] ?>"
                                            <?= $edit_evaluation && $edit_evaluation['evaluation_type_id'] == $type['id'] ? 'selected' : '' ?>>
                                        <?= htmlspecialchars($type['name']) ?> (الدرجة النهائية: <?= $type['max_score'] ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="score" class="form-label">الدرجة *</label>
                            <input type="number" step="0.01" class="form-control" id="score" name="score" required
                                   value="<?= $edit_evaluation ? $edit_evaluation['score'] : '' ?>">
                            <div class="form-text">الدرجة النهائية: <span id="maxScoreDisplay">-</span></div>
                        </div>
                        <div class="mb-3">
                            <label for="evaluation_date" class="form-label">تاريخ التقييم *</label>
                            <input type="date" class="form-control" id="evaluation_date" name="evaluation_date" required
                                   value="<?= $edit_evaluation ? $edit_evaluation['evaluation_date'] : date('Y-m-d') ?>">
                        </div>
                        <div class="mb-3">
                            <label for="notes" class="form-label">الملاحظات</label>
                            <textarea class="form-control" id="notes" name="notes" rows="3"
                                      placeholder="ملاحظات إضافية حول التقييم"><?= $edit_evaluation ? htmlspecialchars($edit_evaluation['notes']) : '' ?></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                        <button type="submit" class="btn btn-primary">
                            <?= $edit_evaluation ? 'تحديث التقييم' : 'إضافة التقييم' ?>
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Update max score display when evaluation type changes
        document.getElementById('evaluation_type_id').addEventListener('change', function() {
            const selectedOption = this.options[this.selectedIndex];
            const maxScore = selectedOption.getAttribute('data-max-score');
            document.getElementById('maxScoreDisplay').textContent = maxScore || '-';
            
            // Update score input max attribute
            const scoreInput = document.getElementById('score');
            if (maxScore) {
                scoreInput.setAttribute('max', maxScore);
            } else {
                scoreInput.removeAttribute('max');
            }
        });
        
        // Initialize max score display
        document.getElementById('evaluation_type_id').dispatchEvent(new Event('change'));
        
        // Student Performance Chart
        <?php if ($view_mode === 'detailed' && !empty($evaluations)): ?>
        const studentCtx = document.getElementById('studentChart').getContext('2d');
        new Chart(studentCtx, {
            type: 'radar',
            data: {
                labels: [<?= implode(',', array_map(function($e) { return '"' . htmlspecialchars($e['evaluation_type_name']) . '"'; }, $evaluations)) ?>],
                datasets: [{
                    label: 'النسبة المئوية',
                    data: [<?= implode(',', array_column($evaluations, 'percentage')) ?>],
                    backgroundColor: 'rgba(102, 126, 234, 0.2)',
                    borderColor: 'rgba(102, 126, 234, 1)',
                    borderWidth: 2,
                    pointBackgroundColor: 'rgba(102, 126, 234, 1)'
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    r: {
                        beginAtZero: true,
                        max: 100
                    }
                },
                plugins: {
                    legend: {
                        display: false
                    }
                }
            }
        });
        <?php endif; ?>
        
        // Show modal if editing
        <?php if ($edit_evaluation): ?>
        document.addEventListener('DOMContentLoaded', function() {
            new bootstrap.Modal(document.getElementById('addEvaluationModal')).show();
        });
        <?php endif; ?>
    </script>
</body>
</html>

