<?php
session_start();
require_once '../includes/db.php';
require_once '../includes/security.php';

// التحقق من تسجيل دخول المعلم
if (!isset($_SESSION['teacher_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['teacher_id'];
$message = '';
$error = '';

// معالجة النماذج
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add_parent':
                $name = sanitizeInput($_POST['name']);
                $email = sanitizeInput($_POST['email']);
                $phone = sanitizeInput($_POST['phone']);
                $address = sanitizeInput($_POST['address']);
                $national_id = sanitizeInput($_POST['national_id']);
                $password = $_POST['password'];
                
                if (!validateEmail($email)) {
                    $error = "البريد الإلكتروني غير صحيح";
                } elseif (!validatePassword($password)) {
                    $error = "كلمة المرور يجب أن تكون 8 أحرف على الأقل وتحتوي على حرف كبير وصغير ورقم";
                } else {
                    try {
                        $hashed_password = hashPassword($password);
                        $stmt = $pdo->prepare("INSERT INTO parents (name, email, phone, address, national_id, password) VALUES (?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$name, $email, $phone, $address, $national_id, $hashed_password]);
                        $message = "تم إضافة ولي الأمر بنجاح";
                    } catch (PDOException $e) {
                        if ($e->getCode() == 23000) {
                            $error = "البريد الإلكتروني مستخدم بالفعل";
                        } else {
                            $error = "خطأ في إضافة ولي الأمر";
                            error_log("Add parent error: " . $e->getMessage());
                        }
                    }
                }
                break;
                
            case 'link_student_parent':
                $student_id = $_POST['student_id'];
                $parent_id = $_POST['parent_id'];
                $relationship = $_POST['relationship'];
                $is_primary = isset($_POST['is_primary']) ? 1 : 0;
                
                try {
                    // التحقق من أن الطالب ينتمي للمعلم
                    $check_stmt = $pdo->prepare("SELECT student_id FROM students WHERE student_id = ? AND teacher_id = ?");
                    $check_stmt->execute([$student_id, $teacher_id]);
                    
                    if ($check_stmt->fetch()) {
                        // إضافة الربط
                        $stmt = $pdo->prepare("INSERT INTO student_parent (student_id, parent_id, relationship, is_primary) VALUES (?, ?, ?, ?) ON DUPLICATE KEY UPDATE relationship = ?, is_primary = ?");
                        $stmt->execute([$student_id, $parent_id, $relationship, $is_primary, $relationship, $is_primary]);
                        
                        // تحديث parent_id في جدول الطلاب إذا كان ولي الأمر الأساسي
                        if ($is_primary) {
                            $update_stmt = $pdo->prepare("UPDATE students SET parent_id = ? WHERE student_id = ?");
                            $update_stmt->execute([$parent_id, $student_id]);
                        }
                        
                        $message = "تم ربط الطالب بولي الأمر بنجاح";
                    } else {
                        $error = "الطالب غير موجود أو غير مرتبط بك";
                    }
                } catch (PDOException $e) {
                    $error = "خطأ في ربط الطالب بولي الأمر";
                    error_log("Link student parent error: " . $e->getMessage());
                }
                break;
        }
    }
}

// الحصول على قائمة أولياء الأمور
try {
    $parents_stmt = $pdo->prepare("SELECT * FROM parents WHERE is_active = 1 ORDER BY name");
    $parents_stmt->execute();
    $parents = $parents_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // الحصول على قائمة الطلاب التابعين للمعلم
    $students_stmt = $pdo->prepare("SELECT * FROM students WHERE teacher_id = ? ORDER BY name");
    $students_stmt->execute([$teacher_id]);
    $students = $students_stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // الحصول على الروابط الحالية
    $links_stmt = $pdo->prepare("
        SELECT sp.*, s.name as student_name, p.name as parent_name, p.email as parent_email
        FROM student_parent sp
        JOIN students s ON sp.student_id = s.student_id
        JOIN parents p ON sp.parent_id = p.id
        WHERE s.teacher_id = ?
        ORDER BY s.name, sp.is_primary DESC
    ");
    $links_stmt->execute([$teacher_id]);
    $links = $links_stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (PDOException $e) {
    $error = "خطأ في استرجاع البيانات";
    error_log("Fetch data error: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة أولياء الأمور</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="../assets/css/style.css">
</head>
<body class="bg-light">

<?php include '../includes/header.php'; ?>

<div class="container-fluid">
    <div class="row">
        <?php include '../includes/sidebar.php'; ?>
        
        <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
            <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                <h1 class="h2"><i class="fas fa-user-friends me-2"></i> إدارة أولياء الأمور</h1>
            </div>

            <?php if ($message): ?>
                <div class="alert alert-success alert-dismissible fade show">
                    <i class="fas fa-check-circle me-2"></i> <?= htmlspecialchars($message) ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                </div>
            <?php endif; ?>

            <?php if ($error): ?>
                <div class="alert alert-danger alert-dismissible fade show">
                    <i class="fas fa-exclamation-circle me-2"></i> <?= htmlspecialchars($error) ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                </div>
            <?php endif; ?>

            <!-- أزرار الإجراءات -->
            <div class="row mb-4">
                <div class="col-md-6">
                    <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addParentModal">
                        <i class="fas fa-plus me-1"></i> إضافة ولي أمر جديد
                    </button>
                </div>
                <div class="col-md-6">
                    <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#linkStudentParentModal">
                        <i class="fas fa-link me-1"></i> ربط طالب بولي أمر
                    </button>
                </div>
            </div>

            <!-- قائمة الروابط الحالية -->
            <div class="card mb-4">
                <div class="card-header">
                    <h5><i class="fas fa-link me-2"></i> الروابط الحالية بين الطلاب وأولياء الأمور</h5>
                </div>
                <div class="card-body">
                    <?php if (empty($links)): ?>
                        <div class="text-center text-muted py-4">
                            <i class="fas fa-link fa-3x mb-3"></i>
                            <p>لا توجد روابط بين الطلاب وأولياء الأمور</p>
                        </div>
                    <?php else: ?>
                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>الطالب</th>
                                        <th>ولي الأمر</th>
                                        <th>البريد الإلكتروني</th>
                                        <th>صلة القرابة</th>
                                        <th>ولي أمر أساسي</th>
                                        <th>تاريخ الربط</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($links as $link): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($link['student_name']) ?></td>
                                            <td><?= htmlspecialchars($link['parent_name']) ?></td>
                                            <td><?= htmlspecialchars($link['parent_email']) ?></td>
                                            <td>
                                                <span class="badge bg-info">
                                                    <?php
                                                    $relationships = [
                                                        'father' => 'الأب',
                                                        'mother' => 'الأم',
                                                        'guardian' => 'الوصي',
                                                        'other' => 'أخرى'
                                                    ];
                                                    echo $relationships[$link['relationship']] ?? $link['relationship'];
                                                    ?>
                                                </span>
                                            </td>
                                            <td>
                                                <?php if ($link['is_primary']): ?>
                                                    <span class="badge bg-success">نعم</span>
                                                <?php else: ?>
                                                    <span class="badge bg-secondary">لا</span>
                                                <?php endif; ?>
                                            </td>
                                            <td><?= date('Y-m-d', strtotime($link['created_at'])) ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <!-- قائمة أولياء الأمور -->
            <div class="card">
                <div class="card-header">
                    <h5><i class="fas fa-users me-2"></i> قائمة أولياء الأمور</h5>
                </div>
                <div class="card-body">
                    <?php if (empty($parents)): ?>
                        <div class="text-center text-muted py-4">
                            <i class="fas fa-users fa-3x mb-3"></i>
                            <p>لا توجد أولياء أمور مسجلين</p>
                        </div>
                    <?php else: ?>
                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>الاسم</th>
                                        <th>البريد الإلكتروني</th>
                                        <th>الهاتف</th>
                                        <th>العنوان</th>
                                        <th>تاريخ التسجيل</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($parents as $parent): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($parent['name']) ?></td>
                                            <td><?= htmlspecialchars($parent['email']) ?></td>
                                            <td><?= htmlspecialchars($parent['phone']) ?></td>
                                            <td><?= htmlspecialchars($parent['address']) ?></td>
                                            <td><?= date('Y-m-d', strtotime($parent['created_at'])) ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </main>
    </div>
</div>

<!-- نافذة إضافة ولي أمر جديد -->
<div class="modal fade" id="addParentModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title"><i class="fas fa-plus me-2"></i> إضافة ولي أمر جديد</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <form method="post">
                <input type="hidden" name="action" value="add_parent">
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="form-label">الاسم الكامل</label>
                            <input type="text" name="name" class="form-control" required>
                        </div>
                        <div class="col-md-6 mb-3">
                            <label class="form-label">البريد الإلكتروني</label>
                            <input type="email" name="email" class="form-control" required>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="form-label">رقم الهاتف</label>
                            <input type="tel" name="phone" class="form-control">
                        </div>
                        <div class="col-md-6 mb-3">
                            <label class="form-label">الرقم القومي</label>
                            <input type="text" name="national_id" class="form-control">
                        </div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">العنوان</label>
                        <textarea name="address" class="form-control" rows="2"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">كلمة المرور</label>
                        <input type="password" name="password" class="form-control" required>
                        <div class="form-text">يجب أن تكون 8 أحرف على الأقل وتحتوي على حرف كبير وصغير ورقم</div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                    <button type="submit" class="btn btn-primary">
                        <i class="fas fa-save me-1"></i> حفظ
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- نافذة ربط طالب بولي أمر -->
<div class="modal fade" id="linkStudentParentModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title"><i class="fas fa-link me-2"></i> ربط طالب بولي أمر</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <form method="post">
                <input type="hidden" name="action" value="link_student_parent">
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">الطالب</label>
                        <select name="student_id" class="form-select" required>
                            <option value="">اختر الطالب</option>
                            <?php foreach ($students as $student): ?>
                                <option value="<?= $student['student_id'] ?>">
                                    <?= htmlspecialchars($student['name']) ?> - <?= htmlspecialchars($student['grade_level']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">ولي الأمر</label>
                        <select name="parent_id" class="form-select" required>
                            <option value="">اختر ولي الأمر</option>
                            <?php foreach ($parents as $parent): ?>
                                <option value="<?= $parent['id'] ?>">
                                    <?= htmlspecialchars($parent['name']) ?> - <?= htmlspecialchars($parent['email']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">صلة القرابة</label>
                        <select name="relationship" class="form-select" required>
                            <option value="">اختر صلة القرابة</option>
                            <option value="father">الأب</option>
                            <option value="mother">الأم</option>
                            <option value="guardian">الوصي</option>
                            <option value="other">أخرى</option>
                        </select>
                    </div>
                    
                    <div class="mb-3">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="is_primary" id="isPrimary">
                            <label class="form-check-label" for="isPrimary">
                                ولي أمر أساسي
                            </label>
                            <div class="form-text">ولي الأمر الأساسي هو المسؤول الرئيسي عن الطالب</div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إلغاء</button>
                    <button type="submit" class="btn btn-success">
                        <i class="fas fa-link me-1"></i> ربط
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

