<?php
session_start();
require_once '../includes/db.php';

// Check if user is logged in and is a teacher
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'teacher') {
    header('Location: ../login.php');
    exit();
}

$teacher_id = $_SESSION['user_id'];

// Get filter parameters
$month = $_GET['month'] ?? date('m');
$year = $_GET['year'] ?? date('Y');
$group_filter = $_GET['group'] ?? 'all';

// Calculate revenue for groups
function calculateGroupRevenue($pdo, $teacher_id, $month, $year, $group_filter) {
    $where_clause = "WHERE sg.teacher_id = ?";
    $params = [$teacher_id];
    
    if ($group_filter !== 'all') {
        $where_clause .= " AND sg.id = ?";
        $params[] = $group_filter;
    }
    
    $sql = "
        SELECT 
            sg.id,
            sg.name,
            sg.type,
            sg.price_per_student,
            sg.payment_type,
            COUNT(s.student_id) as student_count,
            (COUNT(s.student_id) * sg.price_per_student) as total_revenue
        FROM study_groups sg
        LEFT JOIN students s ON sg.id = s.group_id
        $where_clause
        GROUP BY sg.id
        ORDER BY sg.name
    ";
    
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    return $stmt->fetchAll();
}

// Calculate revenue for individual students
function calculateIndividualRevenue($pdo, $teacher_id, $month, $year) {
    $sql = "
        SELECT 
            s.student_id,
            s.name,
            s.individual_price,
            s.payment_type,
            s.individual_price as total_revenue
        FROM students s
        WHERE s.teacher_id = ? AND s.group_id IS NULL AND s.individual_price IS NOT NULL
        ORDER BY s.name
    ";
    
    $stmt = $pdo->prepare($sql);
    $stmt->execute([$teacher_id]);
    return $stmt->fetchAll();
}

// Get attendance-based revenue (for per_session payments)
function calculateAttendanceRevenue($pdo, $teacher_id, $month, $year) {
    $sql = "
        SELECT 
            sg.name as group_name,
            sg.type,
            sg.price_per_student,
            COUNT(a.id) as total_sessions,
            COUNT(DISTINCT s.student_id) as unique_students,
            (COUNT(a.id) * sg.price_per_student) as attendance_revenue
        FROM attendance a
        JOIN students s ON a.student_id = s.student_id
        JOIN study_groups sg ON s.group_id = sg.id
        WHERE sg.teacher_id = ? 
        AND sg.payment_type = 'per_session'
        AND MONTH(a.date) = ? 
        AND YEAR(a.date) = ?
        AND a.status = 'present'
        GROUP BY sg.id
        ORDER BY sg.name
    ";
    
    $stmt = $pdo->prepare($sql);
    $stmt->execute([$teacher_id, $month, $year]);
    return $stmt->fetchAll();
}

// Get all groups for filter dropdown
$stmt = $pdo->prepare("SELECT id, name, type FROM study_groups WHERE teacher_id = ? ORDER BY name");
$stmt->execute([$teacher_id]);
$all_groups = $stmt->fetchAll();

// Calculate revenues
$group_revenues = calculateGroupRevenue($pdo, $teacher_id, $month, $year, $group_filter);
$individual_revenues = calculateIndividualRevenue($pdo, $teacher_id, $month, $year);
$attendance_revenues = calculateAttendanceRevenue($pdo, $teacher_id, $month, $year);

// Calculate totals
$total_monthly_revenue = 0;
$total_session_revenue = 0;
$total_individual_revenue = 0;

foreach ($group_revenues as $group) {
    if ($group['payment_type'] === 'monthly') {
        $total_monthly_revenue += $group['total_revenue'];
    }
}

foreach ($attendance_revenues as $attendance) {
    $total_session_revenue += $attendance['attendance_revenue'];
}

foreach ($individual_revenues as $individual) {
    $total_individual_revenue += $individual['total_revenue'];
}

$grand_total = $total_monthly_revenue + $total_session_revenue + $total_individual_revenue;
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تقارير الإيرادات</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        body { font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif; }
        .sidebar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075); }
        .btn-primary { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); border: none; }
        .revenue-card { transition: transform 0.2s; }
        .revenue-card:hover { transform: translateY(-2px); }
        .chart-container { position: relative; height: 300px; }
    </style>
</head>
<body class="bg-light">
    <div class="container-fluid">
        <div class="row">
            <!-- Sidebar -->
            <div class="col-md-3 col-lg-2 px-0">
                <?php include '../includes/sidebar.php'; ?>
            </div>
            
            <!-- Main Content -->
            <div class="col-md-9 col-lg-10">
                <div class="container-fluid py-4">
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <h2><i class="fas fa-chart-line me-2"></i>تقارير الإيرادات</h2>
                        <a href="dashboard.php" class="btn btn-outline-secondary">
                            <i class="fas fa-arrow-right me-2"></i>العودة للوحة التحكم
                        </a>
                    </div>

                    <!-- Filters -->
                    <div class="card mb-4">
                        <div class="card-body">
                            <form method="GET" class="row g-3">
                                <div class="col-md-3">
                                    <label for="month" class="form-label">الشهر</label>
                                    <select class="form-select" id="month" name="month">
                                        <?php for ($m = 1; $m <= 12; $m++): ?>
                                            <option value="<?= sprintf('%02d', $m) ?>" <?= $month == sprintf('%02d', $m) ? 'selected' : '' ?>>
                                                <?= date('F', mktime(0, 0, 0, $m, 1)) ?>
                                            </option>
                                        <?php endfor; ?>
                                    </select>
                                </div>
                                <div class="col-md-3">
                                    <label for="year" class="form-label">السنة</label>
                                    <select class="form-select" id="year" name="year">
                                        <?php for ($y = date('Y') - 2; $y <= date('Y') + 1; $y++): ?>
                                            <option value="<?= $y ?>" <?= $year == $y ? 'selected' : '' ?>><?= $y ?></option>
                                        <?php endfor; ?>
                                    </select>
                                </div>
                                <div class="col-md-4">
                                    <label for="group" class="form-label">المجموعة</label>
                                    <select class="form-select" id="group" name="group">
                                        <option value="all" <?= $group_filter === 'all' ? 'selected' : '' ?>>جميع المجموعات</option>
                                        <?php foreach ($all_groups as $group): ?>
                                            <option value="<?= $group['id'] ?>" <?= $group_filter == $group['id'] ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($group['name']) ?> (<?= $group['type'] === 'public' ? 'عامة' : ($group['type'] === 'private' ? 'خاصة' : 'فردية') ?>)
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="col-md-2">
                                    <label class="form-label">&nbsp;</label>
                                    <button type="submit" class="btn btn-primary w-100">
                                        <i class="fas fa-filter me-2"></i>تطبيق
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- Revenue Summary Cards -->
                    <div class="row mb-4">
                        <div class="col-md-3">
                            <div class="card revenue-card bg-primary text-white">
                                <div class="card-body">
                                    <div class="d-flex justify-content-between">
                                        <div>
                                            <h6 class="card-title">الإيرادات الشهرية</h6>
                                            <h4><?= number_format($total_monthly_revenue, 2) ?> ج.م</h4>
                                        </div>
                                        <i class="fas fa-calendar-alt fa-2x opacity-75"></i>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card revenue-card bg-success text-white">
                                <div class="card-body">
                                    <div class="d-flex justify-content-between">
                                        <div>
                                            <h6 class="card-title">إيرادات الحصص</h6>
                                            <h4><?= number_format($total_session_revenue, 2) ?> ج.م</h4>
                                        </div>
                                        <i class="fas fa-clock fa-2x opacity-75"></i>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card revenue-card bg-info text-white">
                                <div class="card-body">
                                    <div class="d-flex justify-content-between">
                                        <div>
                                            <h6 class="card-title">الطلاب الفرديين</h6>
                                            <h4><?= number_format($total_individual_revenue, 2) ?> ج.م</h4>
                                        </div>
                                        <i class="fas fa-user fa-2x opacity-75"></i>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="card revenue-card bg-warning text-white">
                                <div class="card-body">
                                    <div class="d-flex justify-content-between">
                                        <div>
                                            <h6 class="card-title">إجمالي الإيرادات</h6>
                                            <h4><?= number_format($grand_total, 2) ?> ج.م</h4>
                                        </div>
                                        <i class="fas fa-chart-line fa-2x opacity-75"></i>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Revenue Chart -->
                    <div class="row mb-4">
                        <div class="col-md-6">
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">توزيع الإيرادات</h5>
                                </div>
                                <div class="card-body">
                                    <div class="chart-container">
                                        <canvas id="revenueChart"></canvas>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">إيرادات المجموعات</h5>
                                </div>
                                <div class="card-body">
                                    <div class="chart-container">
                                        <canvas id="groupChart"></canvas>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Detailed Revenue Tables -->
                    <div class="row">
                        <!-- Group Revenue Table -->
                        <div class="col-md-6 mb-4">
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">إيرادات المجموعات</h5>
                                </div>
                                <div class="card-body">
                                    <?php if (empty($group_revenues)): ?>
                                        <p class="text-muted text-center">لا توجد بيانات إيرادات للمجموعات</p>
                                    <?php else: ?>
                                        <div class="table-responsive">
                                            <table class="table table-sm">
                                                <thead>
                                                    <tr>
                                                        <th>المجموعة</th>
                                                        <th>النوع</th>
                                                        <th>عدد الطلاب</th>
                                                        <th>السعر</th>
                                                        <th>الإجمالي</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php foreach ($group_revenues as $group): ?>
                                                        <tr>
                                                            <td><?= htmlspecialchars($group['name']) ?></td>
                                                            <td>
                                                                <span class="badge bg-<?= $group['type'] === 'public' ? 'success' : ($group['type'] === 'private' ? 'primary' : 'info') ?>">
                                                                    <?= $group['type'] === 'public' ? 'عامة' : ($group['type'] === 'private' ? 'خاصة' : 'فردية') ?>
                                                                </span>
                                                            </td>
                                                            <td><?= $group['student_count'] ?></td>
                                                            <td><?= number_format($group['price_per_student'], 2) ?> ج.م</td>
                                                            <td><strong><?= number_format($group['total_revenue'], 2) ?> ج.م</strong></td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>

                        <!-- Individual Students Revenue Table -->
                        <div class="col-md-6 mb-4">
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">إيرادات الطلاب الفرديين</h5>
                                </div>
                                <div class="card-body">
                                    <?php if (empty($individual_revenues)): ?>
                                        <p class="text-muted text-center">لا توجد بيانات إيرادات للطلاب الفرديين</p>
                                    <?php else: ?>
                                        <div class="table-responsive">
                                            <table class="table table-sm">
                                                <thead>
                                                    <tr>
                                                        <th>اسم الطالب</th>
                                                        <th>نوع الدفع</th>
                                                        <th>السعر</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php foreach ($individual_revenues as $student): ?>
                                                        <tr>
                                                            <td><?= htmlspecialchars($student['name']) ?></td>
                                                            <td>
                                                                <span class="badge bg-<?= $student['payment_type'] === 'monthly' ? 'success' : 'info' ?>">
                                                                    <?= $student['payment_type'] === 'monthly' ? 'شهري' : 'بالحصة' ?>
                                                                </span>
                                                            </td>
                                                            <td><strong><?= number_format($student['individual_price'], 2) ?> ج.م</strong></td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Attendance-based Revenue Table -->
                    <?php if (!empty($attendance_revenues)): ?>
                        <div class="card">
                            <div class="card-header">
                                <h5 class="mb-0">إيرادات الحضور (الدفع بالحصة)</h5>
                            </div>
                            <div class="card-body">
                                <div class="table-responsive">
                                    <table class="table">
                                        <thead>
                                            <tr>
                                                <th>المجموعة</th>
                                                <th>النوع</th>
                                                <th>عدد الحصص</th>
                                                <th>عدد الطلاب</th>
                                                <th>السعر للحصة</th>
                                                <th>إجمالي الإيرادات</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($attendance_revenues as $attendance): ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($attendance['group_name']) ?></td>
                                                    <td>
                                                        <span class="badge bg-<?= $attendance['type'] === 'public' ? 'success' : 'primary' ?>">
                                                            <?= $attendance['type'] === 'public' ? 'عامة' : 'خاصة' ?>
                                                        </span>
                                                    </td>
                                                    <td><?= $attendance['total_sessions'] ?></td>
                                                    <td><?= $attendance['unique_students'] ?></td>
                                                    <td><?= number_format($attendance['price_per_student'], 2) ?> ج.م</td>
                                                    <td><strong><?= number_format($attendance['attendance_revenue'], 2) ?> ج.م</strong></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Revenue Distribution Chart
        const revenueCtx = document.getElementById('revenueChart').getContext('2d');
        new Chart(revenueCtx, {
            type: 'doughnut',
            data: {
                labels: ['إيرادات شهرية', 'إيرادات الحصص', 'طلاب فرديين'],
                datasets: [{
                    data: [<?= $total_monthly_revenue ?>, <?= $total_session_revenue ?>, <?= $total_individual_revenue ?>],
                    backgroundColor: ['#007bff', '#28a745', '#17a2b8'],
                    borderWidth: 2
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'bottom'
                    }
                }
            }
        });

        // Group Revenue Chart
        const groupCtx = document.getElementById('groupChart').getContext('2d');
        new Chart(groupCtx, {
            type: 'bar',
            data: {
                labels: [<?= implode(',', array_map(function($g) { return '"' . htmlspecialchars($g['name']) . '"'; }, $group_revenues)) ?>],
                datasets: [{
                    label: 'الإيرادات (ج.م)',
                    data: [<?= implode(',', array_column($group_revenues, 'total_revenue')) ?>],
                    backgroundColor: '#667eea',
                    borderColor: '#764ba2',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true
                    }
                },
                plugins: {
                    legend: {
                        display: false
                    }
                }
            }
        });
    </script>
</body>
</html>

